// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_PL_H__
#define __INTERNAL_TERRITORY_NAMES_PL_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_PL[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_PL // Polish
        /*     VAT */ "Watykan",
        /*     MCO */ "Monako",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Wyspy Kokosowe|Kokosowe, Wyspy",
        /*     BLM */ "Saint-Barthélemy",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Makau",
        /*     SXM */ "Sint Maarten",
        /*     MAF */ "Saint-Martin",
        /*     NFK */ "Norfolk",
        /*     PCN */ "Pitcairn",
        /*     BVT */ "Wyspa Bouveta|Bouveta, Wyspy",
        /*     BMU */ "Bermudy",
        /*     IOT */ "Brytyjskie Terytorium Oceanu Indyjskiego",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Wyspa Bożego Narodzenia|Bożego Narodzenia, Wyspy",
        /*     WLF */ "Wallis i Futuna",
        /*     VGB */ "Brytyjskie Wyspy Dziewicze|Wyspy Dziewicze, Brytyjskie|Dziewicze, Brytyjskie Wyspy",
        /*     LIE */ "Liechtenstein",
        /*     ABW */ "Aruba",
        /*     MHL */ "Wyspy Marshalla|Marshalla, Wyspy",
        /*     ASM */ "Samoa Amerykańskie",
        /*     COK */ "Wyspy Cooka|Cooka, Wyspy",
        /*     SPM */ "Saint-Pierre i Miquelon",
        /*     NIU */ "Niue",
        /*     KNA */ "Saint Kitts i Nevis",
        /*     CYM */ "Kajmany",
        /*     BES */ "Bonaire, Sint Eustatius i Saba",
        /*     MDV */ "Malediwy",
        /*     SHN */ "Wyspa Świętej Heleny, Wniebowstąpienia i Tristan da Cunha|Wniebowstąpienia, Wyspy|Tristan da Cunha, Wyspy",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "Wyspy Dziewicze Stanów Zjednoczonych",
        /*     MYT */ "Majotta",
        /*     SJM */ "Svalbard i Jan Mayen",
        /*     VCT */ "Saint Vincent i Grenadyny",
        /*     HMD */ "Wyspy Heard i McDonalda|Heard, Wyspy|McDonalda, Wyspy",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antigua i Barbuda",
        /*     CUW */ "Curaçao",
        /*     SYC */ "Seszele",
        /*     PLW */ "Palau",
        /*     MNP */ "Mariany Północne",
        /*     AND */ "Andora",
        /*     GUM */ "Guam",
        /*     IMN */ "Wyspa Man|Man, Wyspa",
        /*     LCA */ "Saint Lucia",
        /*     FSM */ "Mikronezja",
        /*     SGP */ "Singapur",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominika",
        /*     BHR */ "Bahrajn",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Turks i Caicos",
        /*     STP */ "Wyspy Świętego Tomasza i Książęca|Świętego Tomasza i Książęca, Wyspy|Książęca, Wyspy",
        /*     HKG */ "Hongkong",
        /*     MTQ */ "Martynika",
        /*     FRO */ "Wyspy Owcze|Owcze, Wyspy",
        /*     GLP */ "Gwadelupa",
        /*     COM */ "Komory",
        /*     MUS */ "Mauritius",
        /*     REU */ "Reunion",
        /*     LUX */ "Luksemburg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Georgia Południowa i Sandwich Południowy|Sandwich Południowy",
        /*     PYF */ "Polinezja Francuska",
        /*     CPV */ "Republika Zielonego Przylądka|Zielonego Przylądka",
        /*     TTO */ "Trynidad i Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Francuskie Terytoria Południowe i Antarktyczne",
        /*     PRI */ "Portoryko",
        /*     CYP */ "Cypr",
        /*     LBN */ "Liban",
        /*     JAM */ "Jamajka",
        /*     GMB */ "Gambia",
        /*     QAT */ "Katar",
        /*     FLK */ "Falklandy",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Czarnogóra",
        /*     BHS */ "Bahamy",
        /*     TLS */ "Timor Wschodni",
        /*     SWZ */ "Suazi",
        /*     KWT */ "Kuwejt",
        /*     FJI */ "Fidżi",
        /*     NCL */ "Nowa Kaledonia",
        /*     SVN */ "Słowenia",
        /*     ISR */ "Izrael",
        /*     PSE */ "Palestyna",
        /*     SLV */ "Salwador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Dżibuti",
        /*     MKD */ "Macedonia",
        /*     RWA */ "Rwanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Gwinea Równikowa",
        /*     ALB */ "Albania",
        /*     SLB */ "Wyspy Salomona|Salomona, Wyspy",
        /*     ARM */ "Armenia",
        /*     LSO */ "Lesotho",
        /*     BEL */ "Belgia",
        /*     MDA */ "Mołdawia",
        /*     GNB */ "Gwinea Bissau",
        /*     TWN */ "Tajwan",
        /*     BTN */ "Bhutan",
        /*     CHE */ "Szwajcaria",
        /*     NLD */ "Holandia",
        /*     DNK */ "Dania",
        /*     EST */ "Estonia",
        /*     DOM */ "Dominikana",
        /*     SVK */ "Słowacja",
        /*     CRI */ "Kostaryka",
        /*     BIH */ "Bośnia i Hercegowina",
        /*     HRV */ "Chorwacja",
        /*     TGO */ "Togo",
        /*     LVA */ "Łotwa",
        /*     LTU */ "Litwa",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Gruzja",
        /*     IRL */ "Irlandia",
        /*     SLE */ "Sierra Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "Czechy",
        /*     GUF */ "Gujana Francuska",
        /*     ARE */ "Zjednoczone Emiraty Arabskie",
        /*     AUT */ "Austria",
        /*     AZE */ "Azerbejdżan",
        /*     SRB */ "Serbia",
        /*     JOR */ "Jordania",
        /*     PRT */ "Portugalia",
        /*     HUN */ "Węgry",
        /*     KOR */ "Korea Południowa",
        /*     ISL */ "Islandia",
        /*     GTM */ "Gwatemala",
        /*     CUB */ "Kuba",
        /*     BGR */ "Bułgaria",
        /*     LBR */ "Liberia",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Erytrea",
        /*     MWI */ "Malawi",
        /*     PRK */ "Korea Północna",
        /*     NIC */ "Nikaragua",
        /*     GRC */ "Grecja",
        /*     TJK */ "Tadżykistan",
        /*     BGD */ "Bangladesz",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunezja",
        /*     SUR */ "Surinam",
        /*     URY */ "Urugwaj",
        /*     KHM */ "Kambodża",
        /*     SYR */ "Syria",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Kirgistan",
        /*     BLR */ "Białoruś",
        /*     GUY */ "Gujana",
        /*     LAO */ "Laos",
        /*     ROU */ "Rumunia",
        /*     GHA */ "Ghana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Wielka Brytania",
        /*     GIN */ "Gwinea",
        /*     ECU */ "Ekwador",
        /*     ESH */ "Sahara Zachodnia",
        /*     GAB */ "Gabon",
        /*     NZL */ "Nowa Zelandia",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filipiny",
        /*     ITA */ "Włochy",
        /*     OMN */ "Oman",
        /*     POL */ "Polska",
        /*     CIV */ "Wybrzeże Kości Słoniowej",
        /*     NOR */ "Norwegia",
        /*     MYS */ "Malezja",
        /*     VNM */ "Wietnam",
        /*     FIN */ "Finlandia",
        /*     COG */ "Kongo",
        /*     DEU */ "Niemcy",
        /*     JPN */ "Japonia",
        /*     ZWE */ "Zimbabwe",
        /*     PRY */ "Paragwaj",
        /*     IRQ */ "Irak",
        /*     MAR */ "Maroko",
        /*     UZB */ "Uzbekistan",
        /*     SWE */ "Szwecja",
        /*     PNG */ "Papua-Nowa Gwinea",
        /*     CMR */ "Kamerun",
        /*     TKM */ "Turkmenistan",
        /*     ESP */ "Hiszpania",
        /*     THA */ "Tajlandia",
        /*     YEM */ "Jemen",
        /*     FRA */ "Francja",
        /*     ALA */ "Wyspy Alandzkie|Alandzkie, Wyspy",
        /*     KEN */ "Kenia",
        /*     BWA */ "Botswana",
        /*     MDG */ "Madagaskar",
        /*     UKR */ "Ukraina",
        /*     SSD */ "Sudan Południowy",
        /*     CAF */ "Republika Środkowoafrykańska|Środkowoafrykańska, Republika",
        /*     SOM */ "Somalia",
        /*     AFG */ "Afganistan",
        /*     MMR */ "Mjanma",
        /*     ZMB */ "Zambia",
        /*     CHL */ "Chile",
        /*     TUR */ "Turcja",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mozambik",
        /*     NAM */ "Namibia",
        /*     VEN */ "Wenezuela",
        /*     NGA */ "Nigeria",
        /*     TZA */ "Tanzania",
        /*     EGY */ "Egipt",
        /*     MRT */ "Mauretania",
        /*     BOL */ "Boliwia",
        /*     ETH */ "Etiopia",
        /*     COL */ "Kolumbia",
        /*     ZAF */ "Południowa Afryka",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Niger",
        /*     TCD */ "Czad",
        /*     PER */ "Peru",
        /*     MNG */ "Mongolia",
        /*     IRN */ "Iran",
        /*     LBY */ "Libia",
        /*     SDN */ "Sudan",
        /*     IDN */ "Indonezja",
        /*     DIF */ "Federal District",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Mexico State",
        /*     TAB */ "sos Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatan",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosi",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Grenlandia",
        /*     SAU */ "Arabia Saudyjska",
        /*     COD */ "Demokratyczna Republika Konga|Konga-Kinshasa",
        /*     DZA */ "Algieria",
        /*     KAZ */ "Kazachstan",
        /*     ARG */ "Argentyna",
        /*   IN-DD */ "Daman i Diu",
        /*   IN-DN */ "Dadra i Nagarhaweli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman i Nicobar",
        /*   IN-LD */ "Lakszadiwy",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Pendżab",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Dżammu i Kaszmir",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Bengal Zachodni",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharasztra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "Nowa Południowa Walia",
        /*     ACT */ "Australijskie Terytorium Stołeczne",
        /*     JBT */ "Terytorium Jervis Bay",
        /*   AU-NT */ "Północne terytorium",
        /*   AU-SA */ "Południowa Australia",
        /*     TAS */ "Tasmania",
        /*     VIC */ "Wiktoria",
        /*   AU-WA */ "Zachodnia australia",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Distrito Federal",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraiba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapa",
        /*   BR-CE */ "Ceara",
        /*   BR-AC */ "Akr",
        /*   BR-PR */ "Parana",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondonia",
        /*   BR-SP */ "San Paulo",
        /*   BR-PI */ "Piaui",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhao",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "para",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "Dystrykt Kolumbii",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Hawaje",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "Wirginia Zachodnia",
        /*   US-SC */ "Karolina Południowa",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Wirginia",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pensylwania",
        /*   US-MS */ "Missisipi",
        /*   US-LA */ "Luizjana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "Karolina Północna",
        /*   US-NY */ "Nowy Jork",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Gruzja",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Floryda",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "Dakota Północna",
        /*   US-WA */ "Waszyngton",
        /*   US-SD */ "Dakota Południowa",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Kolorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "Nowy Meksyk",
        /*   US-MT */ "Montana",
        /*   US-CA */ "Kalifornia",
        /*   US-TX */ "Teksas",
        /*   US-AK */ "Alaska",
        /*   CA-BC */ "Brytyjska Kolumbia",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Nowa Fundlandia",
        /*   CA-NB */ "Nowy Brunszwik",
        /*   CA-NS */ "Nowa Szkocja",
        /*   CA-PE */ "Wyspa Księcia Edwarda",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Północno - zachodnie terytoria",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Indie",
        /*     AUS */ "Australia",
        /*     BRA */ "Brazylia",
        /*     USA */ "Stany Zjednoczone",
        /*     MEX */ "Meksyk",
        /*     MOW */ "Moskwa",
        /*     SPE */ "Sankt Petersburg",
        /*     KGD */ "Obwód Kaliningradzki",
        /*   RU-IN */ "Republika Inguszetii",
        /*   RU-AD */ "Republika Adygeja",
        /*   RU-SE */ "Osetia Północna Republika",
        /*   RU-KB */ "Kabardyno-Balkar Republic",
        /*   RU-KC */ "Karaczajo-Cherkess Republic",
        /*   RU-CE */ "Czeczenia",
        /*   RU-CU */ "Chuvash Republic",
        /*     IVA */ "Iwanowo Oblast",
        /*     LIP */ "Obwód lipiecki",
        /*     ORL */ "Obwód Orłowski",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Biełgorod Oblast",
        /*     VLA */ "Obwód włodzimierski",
        /*     KRS */ "Kursk Oblast",
        /*     KLU */ "Obwód Kałuski",
        /*   RU-TT */ "Obwód tambowski",
        /*     BRY */ "Briańsk Oblast",
        /*     YAR */ "Jarosław Oblast",
        /*     RYA */ "Obwód riazański",
        /*     AST */ "Astrachań Oblast",
        /*     MOS */ "Obwód moskiewski",
        /*     SMO */ "Obwód smoleński",
        /*   RU-DA */ "Republiki Dagestan",
        /*     VOR */ "Obwód woroneski",
        /*     NGR */ "Novgorod Oblast",
        /*     PSK */ "Obwód Psków",
        /*     KOS */ "Obwód kostromski",
        /*     STA */ "Kraj Stawropolski",
        /*     KDA */ "Kraj Krasnodarski",
        /*   RU-KL */ "Republika Kałmucji",
        /*     TVE */ "Obwód twerski",
        /*     LEN */ "Leningrad Oblast",
        /*     ROS */ "Obwód rostowski",
        /*     VGG */ "Obwód wołgogradzki",
        /*     VLG */ "Wołogziański",
        /*     MUR */ "Murmansk Oblast",
        /*   RU-KR */ "Republika Karelia",
        /*     NEN */ "Nieniecki Okręg Autonomiczny",
        /*   RU-KO */ "Republika Komi",
        /*     ARK */ "Archangielsk Oblast",
        /*   RU-MO */ "Republika Mordowia",
        /*     NIZ */ "Obwód niżnonowogrodzki",
        /*     PNZ */ "Penza Oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Republika Mari Eł",
        /*     ORE */ "Orenburg Oblast",
        /*     ULY */ "Obwód uljanowski",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "Republika Baszkirii",
        /*   RU-UD */ "Republika Udmurt",
        /*   RU-TA */ "Republika Tatarstan",
        /*     SAM */ "Samara Oblast",
        /*     SAR */ "Obwód saratowski",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Chanty-Mansi",
        /*     SVE */ "Obwód swierdłowski",
        /*     TYU */ "Obwód Tiumeń",
        /*     KGN */ "Obwód kurgański",
        /*   RU-CH */ "Obwód czelabiński",
        /*   RU-BU */ "Republika Buriacja",
        /*     ZAB */ "Kraj Zabajkalski",
        /*     IRK */ "Obwód irkucki",
        /*     NVS */ "Obwód Nowosybirsk",
        /*     TOM */ "Obwód Tomski",
        /*     OMS */ "Omsk Oblast",
        /*   RU-KK */ "Republika Chakasja",
        /*     KEM */ "Kemerowo Oblast",
        /*   RU-AL */ "Republika Ałtaju",
        /*     ALT */ "Kraj Ałtajski",
        /*   RU-TY */ "Republika Tuwy",
        /*     KYA */ "Kraj Krasnojarski",
        /*     MAG */ "Obwód magadański",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kraj Kamczacki",
        /*     SAK */ "Obwód sachaliński",
        /*   RU-PO */ "Nadmorskim",
        /*     YEV */ "Żydowski Obwód Autonomiczny",
        /*     KHA */ "Kraj Chabarowski",
        /*     AMU */ "Obwód amurski",
        /*   RU-SA */ "Republika Sacha|Jakucja Republika",
        /*     CAN */ "Kanada",
        /*     RUS */ "Rosja",
        /*   CN-SH */ "Szanghaj",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Pekin",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Mongolia Wewnętrzna",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangxi Zhuang",
        /*   CN-SC */ "Syczuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tybet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Xinjiang Ujgur",
        /*     CHN */ "Chiny",
        /*     UMI */ "Dalekie Wyspy Mniejsze Stanów Zjednoczonych",
        /*     CPT */ "Wyspa Clippertona",
        /*     ATA */ "Antarktyka",
        /*     AAA */ "International|Worldwide|Ziemia"
#else // MAPCODE_SUPPORT_LANGUAGE_PL
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_PL
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_PL_H__
