// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef __INTERNAL_TERRITORY_SEARCH_H__
#define __INTERNAL_TERRITORY_SEARCH_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (dividemaps.cpp), DO NOT CHANGE OR PRETTIFY ***

#ifdef NO_FAST_ENCODE
#error
#error "NO_FAST_ENCODE cannot be specified in this file"
#endif

static const int REDIVAR[] = {
        27984500, 1383,
        2537718, 676,
        12842450, 332,
        -55514813, 174,
        -6059000, 101,
        -117350000, 46,
        -15190488, 30,
        -167832984, 25,
        -28175000, 21,
        2, TERRITORY_NZL, TERRITORY_ATA,
        3, TERRITORY_NIU, TERRITORY_TON, TERRITORY_FJI,
        4, TERRITORY_PCN, TERRITORY_COK, TERRITORY_PYF, TERRITORY_ATA,
        -171131108, 41,
        -11977500, 38,
        3, TERRITORY_WLF, TERRITORY_WSM, TERRITORY_FJI,
        2, TERRITORY_TKL, TERRITORY_KIR,
        4, TERRITORY_ASM, TERRITORY_COK, TERRITORY_KIR, TERRITORY_PYF,
        -18715000, 75,
        -64521250, 57,
        6, TERRITORY_CHL, TERRITORY_BOL, TERRITORY_PER, TERRITORY_ARG, TERRITORY_BRA, TERRITORY_ATA,
        -28845346, 67,
        7, TERRITORY_FLK, TERRITORY_URY, TERRITORY_PER, TERRITORY_ARG, TERRITORY_BR_RS, TERRITORY_BRA, TERRITORY_ATA,
        7, TERRITORY_PRY, TERRITORY_BOL, TERRITORY_PER, TERRITORY_ARG, TERRITORY_BR_RS, TERRITORY_BR_MS, TERRITORY_BRA,
        -59298500, 93,
        -15616000, 85,
        5, TERRITORY_CHL, TERRITORY_BOL, TERRITORY_PER, TERRITORY_BR_MT, TERRITORY_BRA,
        7, TERRITORY_BOL, TERRITORY_PER, TERRITORY_BR_AC, TERRITORY_BR_RO, TERRITORY_BR_MT, TERRITORY_BR_AM,
        TERRITORY_BRA,
        7, TERRITORY_BOL, TERRITORY_PER, TERRITORY_BR_MS, TERRITORY_BR_MT, TERRITORY_BR_PA, TERRITORY_BR_AM,
        TERRITORY_BRA,
        -68556225, 144,
        9859904, 130,
        -74589500, 124,
        4965000, 118,
        -121020000, 114,
        2, TERRITORY_KIR, TERRITORY_UMI,
        3, TERRITORY_ECU, TERRITORY_COL, TERRITORY_PER,
        5, TERRITORY_CRI, TERRITORY_PAN, TERRITORY_COL, TERRITORY_PER, TERRITORY_UMI,
        5, TERRITORY_VEN, TERRITORY_COL, TERRITORY_PER, TERRITORY_BR_AM, TERRITORY_BRA,
        -82018000, 138,
        5, TERRITORY_CRI, TERRITORY_NIC, TERRITORY_PER, TERRITORY_UMI, TERRITORY_CPT,
        5, TERRITORY_ABW, TERRITORY_CUW, TERRITORY_VEN, TERRITORY_COL, TERRITORY_PER,
        9263257, 156,
        9, TERRITORY_SUR, TERRITORY_GUY, TERRITORY_VEN, TERRITORY_COL, TERRITORY_PER, TERRITORY_BR_RR, TERRITORY_BR_PA,
        TERRITORY_BR_AM, TERRITORY_BRA,
        -62448678, 163,
        4, TERRITORY_BES, TERRITORY_VEN, TERRITORY_COL, TERRITORY_PER,
        12365000, 170,
        4, TERRITORY_GRD, TERRITORY_TTO, TERRITORY_VEN, TERRITORY_PER,
        3, TERRITORY_GRD, TERRITORY_VCT, TERRITORY_PER,
        -8371850, 258,
        -47007000, 205,
        -19580300, 193,
        12, TERRITORY_URY, TERRITORY_PRY, TERRITORY_PER, TERRITORY_ARG, TERRITORY_BR_SC, TERRITORY_BR_PR,
        TERRITORY_BR_SP, TERRITORY_BR_RS, TERRITORY_BR_MS, TERRITORY_BR_MG, TERRITORY_BRA, TERRITORY_ATA,
        11, TERRITORY_PRY, TERRITORY_PER, TERRITORY_BR_DF, TERRITORY_BR_TO, TERRITORY_BR_MA, TERRITORY_BR_GO,
        TERRITORY_BR_MS, TERRITORY_BR_MG, TERRITORY_BR_MT, TERRITORY_BR_PA, TERRITORY_BRA,
        -11963846, 239,
        -42991000, 225,
        -19580300, 218,
        6, TERRITORY_PER, TERRITORY_BR_RJ, TERRITORY_BR_SP, TERRITORY_BR_MG, TERRITORY_BRA, TERRITORY_ATA,
        6, TERRITORY_PER, TERRITORY_BR_TO, TERRITORY_BR_GO, TERRITORY_BR_BA, TERRITORY_BR_MG, TERRITORY_BRA,
        -47050000, 231,
        3, TERRITORY_SGS, TERRITORY_PER, TERRITORY_ATA,
        7, TERRITORY_SHN, TERRITORY_PER, TERRITORY_BR_RJ, TERRITORY_BR_ES, TERRITORY_BR_BA, TERRITORY_BR_MG,
        TERRITORY_BRA,
        -39287170, 250,
        8, TERRITORY_PER, TERRITORY_BR_PE, TERRITORY_BR_PI, TERRITORY_BR_TO, TERRITORY_BR_MA, TERRITORY_BR_BA,
        TERRITORY_BR_PA, TERRITORY_BRA,
        7, TERRITORY_SHN, TERRITORY_PER, TERRITORY_BR_SE, TERRITORY_BR_AL, TERRITORY_BR_PE, TERRITORY_BR_BA,
        TERRITORY_BRA,
        -23810000, 294,
        -1916920, 280,
        -41616550, 272,
        7, TERRITORY_PER, TERRITORY_BR_PI, TERRITORY_BR_TO, TERRITORY_BR_MA, TERRITORY_BR_MT, TERRITORY_BR_PA,
        TERRITORY_BRA,
        7, TERRITORY_PER, TERRITORY_BR_RN, TERRITORY_BR_PB, TERRITORY_BR_PE, TERRITORY_BR_CE, TERRITORY_BR_PI,
        TERRITORY_BRA,
        -49307328, 289,
        6, TERRITORY_GUF, TERRITORY_SUR, TERRITORY_PER, TERRITORY_BR_AP, TERRITORY_BR_PA, TERRITORY_BRA,
        4, TERRITORY_PER, TERRITORY_BR_MA, TERRITORY_BR_PA, TERRITORY_BRA,
        10775000, 312,
        -5530500, 305,
        6, TERRITORY_SHN, TERRITORY_SLE, TERRITORY_LBR, TERRITORY_GIN, TERRITORY_CIV, TERRITORY_MLI,
        6, TERRITORY_TGO, TERRITORY_BEN, TERRITORY_GHA, TERRITORY_BFA, TERRITORY_CIV, TERRITORY_MLI,
        -6579285, 319,
        4, TERRITORY_GNB, TERRITORY_SEN, TERRITORY_GIN, TERRITORY_MLI,
        11426925, 327,
        5, TERRITORY_TGO, TERRITORY_BEN, TERRITORY_GHA, TERRITORY_BFA, TERRITORY_MLI,
        4, TERRITORY_BEN, TERRITORY_BFA, TERRITORY_MLI, TERRITORY_NER,
        -85785000, 522,
        19815000, 418,
        -95481000, 355,
        16, TERRITORY_MX_DIF, TERRITORY_MX_TLA, TERRITORY_MX_MOR, TERRITORY_MX_CL, TERRITORY_MX_HID, TERRITORY_MX_MX,
        TERRITORY_MX_PUE, TERRITORY_MX_MIC, TERRITORY_MX_GRO, TERRITORY_MX_VER, TERRITORY_MX_JAL, TERRITORY_MX_OAX,
        TERRITORY_US_HI, TERRITORY_USA, TERRITORY_MEX, TERRITORY_UMI,
        17649500, 391,
        -90249500, 377,
        14015959, 364,
        2, TERRITORY_GTM, TERRITORY_PER,
        -92914500, 372,
        5, TERRITORY_MX_TAB, TERRITORY_MX_VER, TERRITORY_MX_CHP, TERRITORY_MX_OAX, TERRITORY_MEX,
        4, TERRITORY_GTM, TERRITORY_MX_TAB, TERRITORY_MX_CHP, TERRITORY_MEX,
        14491789, 385,
        5, TERRITORY_SLV, TERRITORY_GTM, TERRITORY_HND, TERRITORY_NIC, TERRITORY_PER,
        5, TERRITORY_BLZ, TERRITORY_GTM, TERRITORY_HND, TERRITORY_NIC, TERRITORY_MEX,
        -90690000, 402,
        8, TERRITORY_GTM, TERRITORY_MX_TAB, TERRITORY_MX_CAM, TERRITORY_MX_VER, TERRITORY_MX_CHP, TERRITORY_MX_OAX,
        TERRITORY_USA, TERRITORY_MEX,
        19007500, 412,
        7, TERRITORY_BLZ, TERRITORY_GTM, TERRITORY_MX_ROO, TERRITORY_MX_CAM, TERRITORY_MX_CHP, TERRITORY_USA,
        TERRITORY_MEX,
        5, TERRITORY_MX_YUC, TERRITORY_MX_ROO, TERRITORY_MX_CAM, TERRITORY_USA, TERRITORY_MEX,
        -100679000, 473,
        23113500, 451,
        -104856000, 433,
        8, TERRITORY_MX_NAY, TERRITORY_MX_SIN, TERRITORY_MX_BCS, TERRITORY_MX_JAL, TERRITORY_MX_DUR, TERRITORY_US_HI,
        TERRITORY_USA, TERRITORY_MEX,
        20496000, 441,
        5, TERRITORY_MX_GUA, TERRITORY_MX_MIC, TERRITORY_MX_JAL, TERRITORY_USA, TERRITORY_MEX,
        9, TERRITORY_MX_AGU, TERRITORY_MX_NAY, TERRITORY_MX_GUA, TERRITORY_MX_SLP, TERRITORY_MX_ZAC, TERRITORY_MX_JAL,
        TERRITORY_MX_DUR, TERRITORY_USA, TERRITORY_MEX,
        -104856000, 463,
        9, TERRITORY_MX_SIN, TERRITORY_MX_BCS, TERRITORY_MX_DUR, TERRITORY_MX_SON, TERRITORY_MX_CHH, TERRITORY_US_HI,
        TERRITORY_US_TX, TERRITORY_USA, TERRITORY_MEX,
        9, TERRITORY_MX_SLP, TERRITORY_MX_NLE, TERRITORY_MX_ZAC, TERRITORY_MX_DUR, TERRITORY_MX_COA, TERRITORY_MX_CHH,
        TERRITORY_US_TX, TERRITORY_USA, TERRITORY_MEX,
        22023500, 494,
        -93031500, 488,
        10, TERRITORY_MX_QUE, TERRITORY_MX_HID, TERRITORY_MX_MX, TERRITORY_MX_GUA, TERRITORY_MX_PUE, TERRITORY_MX_MIC,
        TERRITORY_MX_SLP, TERRITORY_MX_VER, TERRITORY_USA, TERRITORY_MEX,
        5, TERRITORY_MX_YUC, TERRITORY_MX_ROO, TERRITORY_MX_CAM, TERRITORY_USA, TERRITORY_MEX,
        -91965000, 512,
        24517000, 505,
        6, TERRITORY_MX_SLP, TERRITORY_MX_NLE, TERRITORY_MX_VER, TERRITORY_MX_TAM, TERRITORY_USA, TERRITORY_MEX,
        6, TERRITORY_MX_NLE, TERRITORY_MX_TAM, TERRITORY_MX_COA, TERRITORY_US_TX, TERRITORY_USA, TERRITORY_MEX,
        24055000, 518,
        3, TERRITORY_MX_YUC, TERRITORY_USA, TERRITORY_MEX,
        3, TERRITORY_US_FL, TERRITORY_USA, TERRITORY_MEX,
        17731984, 599,
        -61364779, 567,
        16901800, 545,
        -62626922, 536,
        5, TERRITORY_BES, TERRITORY_HND, TERRITORY_NIC, TERRITORY_COL, TERRITORY_PER,
        15684879, 542,
        3, TERRITORY_VCT, TERRITORY_DMA, TERRITORY_PER,
        2, TERRITORY_MSR, TERRITORY_GLP,
        -66701997, 557,
        17575000, 553,
        3, TERRITORY_BES, TERRITORY_DOM, TERRITORY_HND,
        3, TERRITORY_BES, TERRITORY_JAM, TERRITORY_DOM,
        17551293, 563,
        3, TERRITORY_KNA, TERRITORY_BES, TERRITORY_ATG,
        3, TERRITORY_BES, TERRITORY_VIR, TERRITORY_ATG,
        14253000, 582,
        -23810000, 576,
        4, TERRITORY_VCT, TERRITORY_BRB, TERRITORY_LCA, TERRITORY_PER,
        5, TERRITORY_GMB, TERRITORY_SEN, TERRITORY_BFA, TERRITORY_MLI, TERRITORY_NER,
        -20139807, 593,
        15684879, 590,
        3, TERRITORY_DMA, TERRITORY_MTQ, TERRITORY_CPV,
        2, TERRITORY_GLP, TERRITORY_CPV,
        5, TERRITORY_SEN, TERRITORY_BFA, TERRITORY_MRT, TERRITORY_MLI, TERRITORY_NER,
        -63821000, 638,
        19812550, 616,
        -68135088, 611,
        5, TERRITORY_CYM, TERRITORY_JAM, TERRITORY_HTI, TERRITORY_DOM, TERRITORY_USA,
        4, TERRITORY_VGB, TERRITORY_VIR, TERRITORY_PRI, TERRITORY_USA,
        -72604230, 629,
        23868000, 625,
        4, TERRITORY_BHS, TERRITORY_HTI, TERRITORY_CUB, TERRITORY_USA,
        3, TERRITORY_BHS, TERRITORY_US_FL, TERRITORY_USA,
        20556500, 635,
        3, TERRITORY_HTI, TERRITORY_DOM, TERRITORY_USA,
        2, TERRITORY_TCA, TERRITORY_USA,
        18772220, 652,
        -62560260, 647,
        4, TERRITORY_BLM, TERRITORY_SXM, TERRITORY_MAF, TERRITORY_AIA,
        4, TERRITORY_ATG, TERRITORY_MRT, TERRITORY_MLI, TERRITORY_NER,
        -422500, 667,
        27433500, 662,
        5, TERRITORY_ESH, TERRITORY_MAR, TERRITORY_MRT, TERRITORY_MLI, TERRITORY_DZA,
        4, TERRITORY_ESH, TERRITORY_MAR, TERRITORY_ESP, TERRITORY_DZA,
        26255000, 673,
        3, TERRITORY_MLI, TERRITORY_NER, TERRITORY_DZA,
        2, TERRITORY_ESP, TERRITORY_DZA,
        10511000, 1056,
        74615395, 878,
        -5098202, 776,
        39063250, 738,
        -20098000, 705,
        29828500, 699,
        -50838844, 693,
        2, TERRITORY_BVT, TERRITORY_ATA,
        5, TERRITORY_LSO, TERRITORY_ZWE, TERRITORY_BWA, TERRITORY_NAM, TERRITORY_ZAF,
        5, TERRITORY_SWZ, TERRITORY_ZWE, TERRITORY_MOZ, TERRITORY_ZAF, TERRITORY_ATA,
        29790000, 725,
        -14533000, 715,
        5, TERRITORY_ZWE, TERRITORY_BWA, TERRITORY_ZMB, TERRITORY_NAM, TERRITORY_AGO,
        26708284, 721,
        3, TERRITORY_ZMB, TERRITORY_AGO, TERRITORY_COD,
        3, TERRITORY_ZMB, TERRITORY_TZA, TERRITORY_COD,
        -14533000, 732,
        4, TERRITORY_MWI, TERRITORY_ZWE, TERRITORY_ZMB, TERRITORY_MOZ,
        5, TERRITORY_MWI, TERRITORY_ZMB, TERRITORY_MOZ, TERRITORY_TZA, TERRITORY_COD,
        -12572492, 758,
        54723903, 749,
        6, TERRITORY_MYT, TERRITORY_MUS, TERRITORY_ATF, TERRITORY_MDG, TERRITORY_MOZ, TERRITORY_ATA,
        -51460000, 754,
        2, TERRITORY_HMD, TERRITORY_ATA,
        3, TERRITORY_MUS, TERRITORY_REU, TERRITORY_ATF,
        45312387, 766,
        5, TERRITORY_COM, TERRITORY_ATF, TERRITORY_MDG, TERRITORY_MOZ, TERRITORY_TZA,
        -8413797, 773,
        4, TERRITORY_SYC, TERRITORY_MUS, TERRITORY_ATF, TERRITORY_MDG,
        2, TERRITORY_IOT, TERRITORY_SYC,
        28158500, 820,
        4039834, 806,
        11520181, 788,
        5, TERRITORY_STP, TERRITORY_GNQ, TERRITORY_GAB, TERRITORY_COG, TERRITORY_CMR,
        -4167751, 794,
        3, TERRITORY_COG, TERRITORY_AGO, TERRITORY_COD,
        21050000, 802,
        5, TERRITORY_GAB, TERRITORY_COG, TERRITORY_CMR, TERRITORY_CAF, TERRITORY_COD,
        3, TERRITORY_SSD, TERRITORY_CAF, TERRITORY_COD,
        6307500, 812,
        3, TERRITORY_BEN, TERRITORY_NGA, TERRITORY_MLI,
        7, TERRITORY_CMR, TERRITORY_SSD, TERRITORY_CAF, TERRITORY_NGA, TERRITORY_TCD, TERRITORY_SDN, TERRITORY_COD,
        1202691, 840,
        40707790, 831,
        6, TERRITORY_RWA, TERRITORY_BDI, TERRITORY_UGA, TERRITORY_KEN, TERRITORY_TZA, TERRITORY_COD,
        -2685000, 836,
        2, TERRITORY_SYC, TERRITORY_KEN,
        3, TERRITORY_MDV, TERRITORY_KEN, TERRITORY_SOM,
        39800000, 859,
        7371000, 855,
        32140000, 850,
        3, TERRITORY_UGA, TERRITORY_SSD, TERRITORY_COD,
        4, TERRITORY_UGA, TERRITORY_KEN, TERRITORY_SSD, TERRITORY_ETH,
        3, TERRITORY_SSD, TERRITORY_ETH, TERRITORY_SDN,
        7876932, 870,
        59255071, 867,
        3, TERRITORY_KEN, TERRITORY_SOM, TERRITORY_ETH,
        2, TERRITORY_MDV, TERRITORY_IND,
        59255071, 875,
        2, TERRITORY_SOM, TERRITORY_ETH,
        2, TERRITORY_IN_LD, TERRITORY_IND,
        -3000000, 985,
        150294500, 942,
        -19119804, 908,
        139475000, 894,
        7, TERRITORY_ATF, TERRITORY_AU_NT, TERRITORY_AU_SA, TERRITORY_AU_WA, TERRITORY_AU_QLD, TERRITORY_AUS,
        TERRITORY_ATA,
        -38750000, 901,
        4, TERRITORY_AU_TAS, TERRITORY_AU_VIC, TERRITORY_AUS, TERRITORY_ATA,
        6, TERRITORY_AU_NSW, TERRITORY_AU_ACT, TERRITORY_AU_SA, TERRITORY_AU_VIC, TERRITORY_AU_QLD, TERRITORY_AUS,
        109235707, 918,
        -11244050, 915,
        2, TERRITORY_CCK, TERRITORY_ATF,
        2, TERRITORY_CXR, TERRITORY_IDN,
        -11930000, 930,
        133495000, 926,
        3, TERRITORY_AU_NT, TERRITORY_AU_WA, TERRITORY_AUS,
        3, TERRITORY_AU_NT, TERRITORY_AU_QLD, TERRITORY_AUS,
        128179500, 936,
        3, TERRITORY_TLS, TERRITORY_IDN, TERRITORY_AUS,
        5, TERRITORY_PNG, TERRITORY_IDN, TERRITORY_AU_NT, TERRITORY_AU_QLD, TERRITORY_AUS,
        -25602173, 957,
        159633500, 953,
        6, TERRITORY_AU_NSW, TERRITORY_AU_JBT, TERRITORY_AU_VIC, TERRITORY_AU_QLD, TERRITORY_AUS, TERRITORY_ATA,
        3, TERRITORY_NFK, TERRITORY_NZL, TERRITORY_ATA,
        162917500, 971,
        -15102950, 965,
        3, TERRITORY_NCL, TERRITORY_AU_QLD, TERRITORY_AUS,
        5, TERRITORY_KIR, TERRITORY_SLB, TERRITORY_PNG, TERRITORY_AU_QLD, TERRITORY_AUS,
        -12405450, 977,
        3, TERRITORY_VUT, TERRITORY_FJI, TERRITORY_NCL,
        172466750, 982,
        2, TERRITORY_KIR, TERRITORY_SLB,
        2, TERRITORY_TUV, TERRITORY_KIR,
        111780000, 1032,
        7762500, 1018,
        94680338, 996,
        4, TERRITORY_MDV, TERRITORY_LKA, TERRITORY_IN_AN, TERRITORY_IND,
        3547250, 1002,
        3, TERRITORY_SGP, TERRITORY_MYS, TERRITORY_IDN,
        98518000, 1008,
        3, TERRITORY_THA, TERRITORY_IDN, TERRITORY_IND,
        6703442, 1014,
        3, TERRITORY_MYS, TERRITORY_THA, TERRITORY_IDN,
        3, TERRITORY_MYS, TERRITORY_VNM, TERRITORY_THA,
        87010150, 1025,
        4, TERRITORY_LKA, TERRITORY_IN_KL, TERRITORY_IN_TN, TERRITORY_IND,
        6, TERRITORY_KHM, TERRITORY_VNM, TERRITORY_THA, TERRITORY_MMR, TERRITORY_IN_AN, TERRITORY_IND,
        179200, 1043,
        163201780, 1040,
        3, TERRITORY_KIR, TERRITORY_PNG, TERRITORY_IDN,
        2, TERRITORY_NRU, TERRITORY_KIR,
        135909365, 1051,
        5, TERRITORY_PLW, TERRITORY_BRN, TERRITORY_PHL, TERRITORY_MYS, TERRITORY_IDN,
        4, TERRITORY_MHL, TERRITORY_FSM, TERRITORY_KIR, TERRITORY_IDN,
        83124000, 1224,
        19960000, 1149,
        51682074, 1098,
        15484010, 1084,
        30218500, 1076,
        9, TERRITORY_BEN, TERRITORY_CMR, TERRITORY_SSD, TERRITORY_CAF, TERRITORY_NGA, TERRITORY_MLI, TERRITORY_NER,
        TERRITORY_TCD, TERRITORY_SDN,
        7, TERRITORY_DJI, TERRITORY_ERI, TERRITORY_YEM, TERRITORY_SSD, TERRITORY_SOM, TERRITORY_ETH, TERRITORY_SDN,
        29805981, 1093,
        6, TERRITORY_MLI, TERRITORY_NER, TERRITORY_TCD, TERRITORY_LBY, TERRITORY_SDN, TERRITORY_DZA,
        4, TERRITORY_ERI, TERRITORY_YEM, TERRITORY_SDN, TERRITORY_SAU,
        15937400, 1133,
        74615395, 1116,
        13175797, 1109,
        4, TERRITORY_YEM, TERRITORY_IN_LD, TERRITORY_IN_KA, TERRITORY_IND,
        6, TERRITORY_YEM, TERRITORY_IN_GA, TERRITORY_IN_KA, TERRITORY_IN_MH, TERRITORY_IND, TERRITORY_CHN,
        13727500, 1125,
        6, TERRITORY_IN_KL, TERRITORY_IN_TN, TERRITORY_IN_KA, TERRITORY_IN_AP, TERRITORY_IN_PY, TERRITORY_IND,
        7, TERRITORY_IN_KA, TERRITORY_IN_TG, TERRITORY_IN_AP, TERRITORY_IN_MH, TERRITORY_IN_PY, TERRITORY_IND,
        TERRITORY_CHN,
        63445071, 1139,
        3, TERRITORY_OMN, TERRITORY_YEM, TERRITORY_SAU,
        9, TERRITORY_IN_CT, TERRITORY_IN_KA, TERRITORY_IN_OR, TERRITORY_IN_TG, TERRITORY_IN_AP, TERRITORY_IN_MH,
        TERRITORY_IN_PY, TERRITORY_IND, TERRITORY_CHN,
        65200071, 1186,
        23600000, 1169,
        24345005, 1162,
        6, TERRITORY_MLI, TERRITORY_NER, TERRITORY_TCD, TERRITORY_LBY, TERRITORY_SDN, TERRITORY_DZA,
        6, TERRITORY_ARE, TERRITORY_OMN, TERRITORY_EGY, TERRITORY_LBY, TERRITORY_SDN, TERRITORY_SAU,
        40464250, 1178,
        6, TERRITORY_ESP, TERRITORY_EGY, TERRITORY_MLI, TERRITORY_LBY, TERRITORY_SAU, TERRITORY_DZA,
        7, TERRITORY_BHR, TERRITORY_QAT, TERRITORY_ARE, TERRITORY_OMN, TERRITORY_PAK, TERRITORY_IRN, TERRITORY_SAU,
        22733000, 1204,
        73363500, 1196,
        5, TERRITORY_IN_DD, TERRITORY_IN_DN, TERRITORY_IN_GJ, TERRITORY_IN_MH, TERRITORY_IND,
        7, TERRITORY_IN_CT, TERRITORY_IN_OR, TERRITORY_IN_GJ, TERRITORY_IN_MP, TERRITORY_IN_MH, TERRITORY_IND,
        TERRITORY_CHN,
        78350000, 1215,
        8, TERRITORY_PAK, TERRITORY_IN_HR, TERRITORY_IN_RJ, TERRITORY_IN_GJ, TERRITORY_IN_MP, TERRITORY_IN_UP,
        TERRITORY_IND, TERRITORY_CHN,
        8, TERRITORY_NPL, TERRITORY_PAK, TERRITORY_IN_CT, TERRITORY_IN_MP, TERRITORY_IN_UP, TERRITORY_IND,
        TERRITORY_CN_XZ, TERRITORY_CHN,
        23445000, 1313,
        101655895, 1264,
        20519475, 1245,
        89826650, 1238,
        5, TERRITORY_IN_CT, TERRITORY_IN_OR, TERRITORY_IN_AP, TERRITORY_IND, TERRITORY_CHN,
        6, TERRITORY_LAO, TERRITORY_THA, TERRITORY_MMR, TERRITORY_IN_AN, TERRITORY_IND, TERRITORY_CHN,
        90515000, 1255,
        7, TERRITORY_BGD, TERRITORY_IN_CT, TERRITORY_IN_JH, TERRITORY_IN_OR, TERRITORY_IN_WB, TERRITORY_IND,
        TERRITORY_CHN,
        8, TERRITORY_BGD, TERRITORY_LAO, TERRITORY_MMR, TERRITORY_IN_TR, TERRITORY_IN_MZ, TERRITORY_IND,
        TERRITORY_CN_YN, TERRITORY_CHN,
        20722500, 1286,
        139657216, 1277,
        8, TERRITORY_KHM, TERRITORY_LAO, TERRITORY_PHL, TERRITORY_VNM, TERRITORY_THA, TERRITORY_CN_HI, TERRITORY_CN_GD,
        TERRITORY_CHN,
        13893260, 1282,
        2, TERRITORY_MHL, TERRITORY_GUM,
        3, TERRITORY_MHL, TERRITORY_MNP, TERRITORY_USA,
        113717500, 1296,
        7, TERRITORY_MAC, TERRITORY_LAO, TERRITORY_VNM, TERRITORY_CN_GD, TERRITORY_CN_GX, TERRITORY_CN_YN,
        TERRITORY_CHN,
        21446500, 1303,
        4, TERRITORY_PHL, TERRITORY_USA, TERRITORY_CN_GD, TERRITORY_CHN,
        117661250, 1309,
        3, TERRITORY_HKG, TERRITORY_CN_GD, TERRITORY_CHN,
        3, TERRITORY_TWN, TERRITORY_USA, TERRITORY_CHN,
        96665000, 1365,
        26270000, 1341,
        90515000, 1330,
        10, TERRITORY_BGD, TERRITORY_IN_ML, TERRITORY_IN_AS, TERRITORY_IN_BR, TERRITORY_IN_CT, TERRITORY_IN_JH,
        TERRITORY_IN_WB, TERRITORY_IN_UP, TERRITORY_IND, TERRITORY_CHN,
        10, TERRITORY_BGD, TERRITORY_MMR, TERRITORY_IN_ML, TERRITORY_IN_NL, TERRITORY_IN_MN, TERRITORY_IN_TR,
        TERRITORY_IN_MZ, TERRITORY_IN_AS, TERRITORY_IND, TERRITORY_CHN,
        89297000, 1354,
        10, TERRITORY_BTN, TERRITORY_BGD, TERRITORY_NPL, TERRITORY_IN_SK, TERRITORY_IN_BR, TERRITORY_IN_WB,
        TERRITORY_IN_UP, TERRITORY_IND, TERRITORY_CN_XZ, TERRITORY_CHN,
        10, TERRITORY_BTN, TERRITORY_BGD, TERRITORY_MMR, TERRITORY_IN_NL, TERRITORY_IN_AR, TERRITORY_IN_AS,
        TERRITORY_IN_WB, TERRITORY_IND, TERRITORY_CN_XZ, TERRITORY_CHN,
        17, TERRITORY_TWN, TERRITORY_JPN, TERRITORY_MMR, TERRITORY_IN_AR, TERRITORY_IND, TERRITORY_USA, TERRITORY_CN_ZJ,
        TERRITORY_CN_FJ, TERRITORY_CN_JX, TERRITORY_CN_GZ, TERRITORY_CN_GD, TERRITORY_CN_HN, TERRITORY_CN_GX,
        TERRITORY_CN_SC, TERRITORY_CN_YN, TERRITORY_CN_XZ, TERRITORY_CHN,
        34765500, 2088,
        43871750, 1765,
        -77419467, 1641,
        37102872, 1538,
        -97787350, 1449,
        33167350, 1426,
        -109250000, 1417,
        29917500, 1410,
        -136451930, 1404,
        2, TERRITORY_US_HI, TERRITORY_USA,
        5, TERRITORY_MX_BCN, TERRITORY_MX_BCS, TERRITORY_MX_SON, TERRITORY_USA, TERRITORY_MEX,
        6, TERRITORY_MX_BCN, TERRITORY_MX_SON, TERRITORY_US_AZ, TERRITORY_US_CA, TERRITORY_USA, TERRITORY_MEX,
        8, TERRITORY_MX_COA, TERRITORY_MX_SON, TERRITORY_MX_CHH, TERRITORY_US_AZ, TERRITORY_US_NM, TERRITORY_US_TX,
        TERRITORY_USA, TERRITORY_MEX,
        -107843500, 1436,
        7, TERRITORY_US_UT, TERRITORY_US_CO, TERRITORY_US_NV, TERRITORY_US_AZ, TERRITORY_US_NM, TERRITORY_US_CA,
        TERRITORY_USA,
        36745500, 1443,
        4, TERRITORY_US_OK, TERRITORY_US_NM, TERRITORY_US_TX, TERRITORY_USA,
        5, TERRITORY_US_OK, TERRITORY_US_KS, TERRITORY_US_CO, TERRITORY_US_NM, TERRITORY_USA,
        35605750, 1496,
        -87869000, 1463,
        9, TERRITORY_US_TN, TERRITORY_US_MS, TERRITORY_US_LA, TERRITORY_US_AL, TERRITORY_US_AR, TERRITORY_US_OK,
        TERRITORY_US_TX, TERRITORY_USA, TERRITORY_MEX,
        33235750, 1483,
        -84127000, 1473,
        5, TERRITORY_US_AL, TERRITORY_US_GA, TERRITORY_US_FL, TERRITORY_USA, TERRITORY_MEX,
        31517000, 1479,
        3, TERRITORY_US_GA, TERRITORY_US_FL, TERRITORY_USA,
        3, TERRITORY_US_SC, TERRITORY_US_GA, TERRITORY_USA,
        -84605000, 1490,
        4, TERRITORY_US_TN, TERRITORY_US_AL, TERRITORY_US_GA, TERRITORY_USA,
        5, TERRITORY_US_SC, TERRITORY_US_TN, TERRITORY_US_NC, TERRITORY_US_GA, TERRITORY_USA,
        -92511000, 1511,
        36745500, 1506,
        5, TERRITORY_US_AR, TERRITORY_US_MO, TERRITORY_US_OK, TERRITORY_US_TX, TERRITORY_USA,
        4, TERRITORY_US_MO, TERRITORY_US_OK, TERRITORY_US_KS, TERRITORY_USA,
        36828750, 1527,
        -86711000, 1521,
        5, TERRITORY_US_KY, TERRITORY_US_TN, TERRITORY_US_AR, TERRITORY_US_MO, TERRITORY_USA,
        5, TERRITORY_US_KY, TERRITORY_US_TN, TERRITORY_US_VA, TERRITORY_US_NC, TERRITORY_USA,
        -85550145, 1534,
        4, TERRITORY_US_KY, TERRITORY_US_IL, TERRITORY_US_MO, TERRITORY_USA,
        3, TERRITORY_US_KY, TERRITORY_US_VA, TERRITORY_USA,
        -93735000, 1580,
        41027722, 1559,
        -103035000, 1552,
        7, TERRITORY_US_NE, TERRITORY_US_UT, TERRITORY_US_WY, TERRITORY_US_CO, TERRITORY_US_NV, TERRITORY_US_CA,
        TERRITORY_USA,
        6, TERRITORY_US_IA, TERRITORY_US_MO, TERRITORY_US_NE, TERRITORY_US_KS, TERRITORY_US_CO, TERRITORY_USA,
        -106550500, 1571,
        9, TERRITORY_US_ID, TERRITORY_US_UT, TERRITORY_US_WY, TERRITORY_US_OR, TERRITORY_US_NV, TERRITORY_US_CA,
        TERRITORY_USA, TERRITORY_CAN, TERRITORY_RUS,
        8, TERRITORY_US_IA, TERRITORY_US_SD, TERRITORY_US_NE, TERRITORY_US_MN, TERRITORY_US_WY, TERRITORY_CA_ON,
        TERRITORY_USA, TERRITORY_CAN,
        41152000, 1620,
        -84227645, 1592,
        7, TERRITORY_US_IN, TERRITORY_US_KY, TERRITORY_US_OH, TERRITORY_US_IA, TERRITORY_US_IL, TERRITORY_US_MO,
        TERRITORY_USA,
        39583250, 1607,
        -79998825, 1602,
        5, TERRITORY_US_WV, TERRITORY_US_KY, TERRITORY_US_VA, TERRITORY_US_OH, TERRITORY_USA,
        4, TERRITORY_US_MD, TERRITORY_US_WV, TERRITORY_US_VA, TERRITORY_USA,
        -80136500, 1614,
        4, TERRITORY_US_WV, TERRITORY_US_OH, TERRITORY_US_PA, TERRITORY_USA,
        5, TERRITORY_US_MD, TERRITORY_US_WV, TERRITORY_US_PA, TERRITORY_US_NY, TERRITORY_USA,
        -85763500, 1632,
        9, TERRITORY_US_IN, TERRITORY_US_IA, TERRITORY_US_IL, TERRITORY_US_WI, TERRITORY_US_MN, TERRITORY_US_MI,
        TERRITORY_CA_ON, TERRITORY_USA, TERRITORY_CAN,
        8, TERRITORY_US_IN, TERRITORY_US_OH, TERRITORY_US_PA, TERRITORY_US_NY, TERRITORY_US_MI, TERRITORY_CA_ON,
        TERRITORY_USA, TERRITORY_CAN,
        40158500, 1711,
        5450000, 1677,
        37488303, 1664,
        -48023000, 1658,
        33142708, 1654,
        2, TERRITORY_BMU, TERRITORY_USA,
        3, TERRITORY_US_VA, TERRITORY_US_NC, TERRITORY_USA,
        5, TERRITORY_GIB, TERRITORY_PRT, TERRITORY_MAR, TERRITORY_ESP, TERRITORY_DZA,
        -48023000, 1674,
        7, TERRITORY_US_DC, TERRITORY_US_DE, TERRITORY_US_NJ, TERRITORY_US_MD, TERRITORY_US_VA, TERRITORY_US_PA,
        TERRITORY_USA,
        2, TERRITORY_PRT, TERRITORY_ESP,
        33983000, 1691,
        29679481, 1686,
        4, TERRITORY_TUN, TERRITORY_EGY, TERRITORY_LBY, TERRITORY_DZA,
        4, TERRITORY_ISR, TERRITORY_PSE, TERRITORY_EGY, TERRITORY_SAU,
        18880000, 1698,
        4, TERRITORY_MLT, TERRITORY_TUN, TERRITORY_ITA, TERRITORY_DZA,
        35765800, 1703,
        2, TERRITORY_CYP, TERRITORY_GRC,
        23381000, 1708,
        2, TERRITORY_ALB, TERRITORY_GRC,
        2, TERRITORY_GRC, TERRITORY_TUR,
        5450000, 1749,
        42383793, 1731,
        -42050000, 1727,
        9, TERRITORY_US_RI, TERRITORY_US_CT, TERRITORY_US_NJ, TERRITORY_US_MA, TERRITORY_US_PA, TERRITORY_US_NY,
        TERRITORY_CA_ON, TERRITORY_USA, TERRITORY_CAN,
        3, TERRITORY_PRT, TERRITORY_ESP, TERRITORY_FRA,
        -66673537, 1742,
        8, TERRITORY_US_NH, TERRITORY_US_VT, TERRITORY_US_MA, TERRITORY_US_ME, TERRITORY_US_NY, TERRITORY_CA_ON,
        TERRITORY_USA, TERRITORY_CAN,
        6, TERRITORY_AND, TERRITORY_ESP, TERRITORY_FRA, TERRITORY_CA_NS, TERRITORY_USA, TERRITORY_CAN,
        15, TERRITORY_VAT, TERRITORY_MCO, TERRITORY_MNE, TERRITORY_MKD, TERRITORY_ALB, TERRITORY_BIH, TERRITORY_HRV,
        TERRITORY_SRB, TERRITORY_BGR, TERRITORY_GRC, TERRITORY_ROU, TERRITORY_ITA, TERRITORY_FRA, TERRITORY_TUR,
        TERRITORY_RUS,
        2192324, 1875,
        49062290, 1805,
        -81486250, 1790,
        18, TERRITORY_US_WI, TERRITORY_US_ND, TERRITORY_US_WA, TERRITORY_US_SD, TERRITORY_US_ID, TERRITORY_US_MN,
        TERRITORY_US_MI, TERRITORY_US_WY, TERRITORY_US_OR, TERRITORY_US_MT, TERRITORY_CA_BC, TERRITORY_CA_AB,
        TERRITORY_CA_ON, TERRITORY_CA_SK, TERRITORY_CA_MB, TERRITORY_USA, TERRITORY_CAN, TERRITORY_RUS,
        14, TERRITORY_SPM, TERRITORY_FRA, TERRITORY_US_NH, TERRITORY_US_VT, TERRITORY_US_ME, TERRITORY_US_NY,
        TERRITORY_CA_ON, TERRITORY_CA_QC, TERRITORY_CA_NL, TERRITORY_CA_NB, TERRITORY_CA_NS, TERRITORY_CA_PE,
        TERRITORY_USA, TERRITORY_CAN,
        -73790750, 1823,
        15, TERRITORY_US_MN, TERRITORY_US_AK, TERRITORY_CA_BC, TERRITORY_CA_AB, TERRITORY_CA_ON, TERRITORY_CA_QC,
        TERRITORY_CA_SK, TERRITORY_CA_MB, TERRITORY_CA_YT, TERRITORY_CA_NT, TERRITORY_CA_NU, TERRITORY_USA,
        TERRITORY_RU_CHU, TERRITORY_CAN, TERRITORY_RUS,
        56700000, 1847,
        -31650000, 1832,
        4, TERRITORY_CA_QC, TERRITORY_CA_NL, TERRITORY_USA, TERRITORY_CAN,
        51255000, 1839,
        4, TERRITORY_GGY, TERRITORY_JEY, TERRITORY_GBR, TERRITORY_FRA,
        -5155300, 1844,
        2, TERRITORY_IRL, TERRITORY_GBR,
        2, TERRITORY_IMN, TERRITORY_GBR,
        -38967380, 1856,
        6, TERRITORY_GRL, TERRITORY_CA_QC, TERRITORY_CA_NL, TERRITORY_CA_NU, TERRITORY_USA, TERRITORY_CAN,
        69452955, 1871,
        -10127000, 1863,
        2, TERRITORY_ISL, TERRITORY_GRL,
        61087500, 1868,
        2, TERRITORY_GBR, TERRITORY_NOR,
        2, TERRITORY_FRO, TERRITORY_NOR,
        3, TERRITORY_SJM, TERRITORY_NOR, TERRITORY_GRL,
        52859250, 1992,
        18692500, 1939,
        47498500, 1917,
        12946250, 1900,
        44896100, 1893,
        11001170, 1890,
        2, TERRITORY_ITA, TERRITORY_FRA,
        2, TERRITORY_SMR, TERRITORY_ITA,
        6, TERRITORY_LIE, TERRITORY_CHE, TERRITORY_AUT, TERRITORY_ITA, TERRITORY_DEU, TERRITORY_FRA,
        47177500, 1909,
        6, TERRITORY_SVN, TERRITORY_BIH, TERRITORY_HRV, TERRITORY_AUT, TERRITORY_HUN, TERRITORY_ITA,
        15602500, 1914,
        2, TERRITORY_AUT, TERRITORY_DEU,
        2, TERRITORY_AUT, TERRITORY_HUN,
        11292500, 1932,
        49234990, 1926,
        4, TERRITORY_CHE, TERRITORY_AUT, TERRITORY_DEU, TERRITORY_FRA,
        5, TERRITORY_LUX, TERRITORY_BEL, TERRITORY_NLD, TERRITORY_DEU, TERRITORY_FRA,
        6, TERRITORY_SVK, TERRITORY_CZE, TERRITORY_AUT, TERRITORY_HUN, TERRITORY_POL, TERRITORY_DEU,
        48523000, 1976,
        19937265, 1955,
        47139000, 1951,
        5, TERRITORY_BIH, TERRITORY_HRV, TERRITORY_SRB, TERRITORY_HUN, TERRITORY_RUS,
        3, TERRITORY_SVK, TERRITORY_HUN, TERRITORY_RUS,
        44323191, 1962,
        4, TERRITORY_SRB, TERRITORY_BGR, TERRITORY_ROU, TERRITORY_RUS,
        24795000, 1971,
        6, TERRITORY_SVK, TERRITORY_SRB, TERRITORY_HUN, TERRITORY_ROU, TERRITORY_UKR, TERRITORY_RUS,
        4, TERRITORY_MDA, TERRITORY_ROU, TERRITORY_UKR, TERRITORY_RUS,
        23039608, 1985,
        6, TERRITORY_SVK, TERRITORY_CZE, TERRITORY_HUN, TERRITORY_POL, TERRITORY_UKR, TERRITORY_RUS,
        6, TERRITORY_BLR, TERRITORY_POL, TERRITORY_UKR, TERRITORY_RU_KRS, TERRITORY_RU_BRY, TERRITORY_RUS,
        28339500, 2045,
        56976000, 2033,
        17383500, 2012,
        55200000, 2009,
        7618000, 2005,
        2, TERRITORY_NLD, TERRITORY_DEU,
        3, TERRITORY_DNK, TERRITORY_POL, TERRITORY_DEU,
        2, TERRITORY_DNK, TERRITORY_SWE,
        55308000, 2020,
        5, TERRITORY_LTU, TERRITORY_BLR, TERRITORY_POL, TERRITORY_RU_KGD, TERRITORY_RUS,
        27083500, 2028,
        5, TERRITORY_LVA, TERRITORY_LTU, TERRITORY_BLR, TERRITORY_SWE, TERRITORY_RUS,
        4, TERRITORY_LVA, TERRITORY_BLR, TERRITORY_RU_PSK, TERRITORY_RUS,
        11, TERRITORY_SJM, TERRITORY_DNK, TERRITORY_EST, TERRITORY_LVA, TERRITORY_NOR, TERRITORY_FIN, TERRITORY_SWE,
        TERRITORY_ALA, TERRITORY_RU_PSK, TERRITORY_RU_LEN, TERRITORY_RUS,
        59533150, 2059,
        11, TERRITORY_BLR, TERRITORY_NOR, TERRITORY_RU_KLU, TERRITORY_RU_BRY, TERRITORY_RU_SMO, TERRITORY_RU_NGR,
        TERRITORY_RU_PSK, TERRITORY_RU_TVE, TERRITORY_RU_LEN, TERRITORY_RU_VLG, TERRITORY_RUS,
        34171500, 2077,
        63834000, 2070,
        6, TERRITORY_NOR, TERRITORY_FIN, TERRITORY_RU_SPE, TERRITORY_RU_LEN, TERRITORY_RU_KR, TERRITORY_RUS,
        6, TERRITORY_SJM, TERRITORY_NOR, TERRITORY_FIN, TERRITORY_RU_MUR, TERRITORY_RU_KR, TERRITORY_RUS,
        63834000, 2084,
        4, TERRITORY_RU_LEN, TERRITORY_RU_VLG, TERRITORY_RU_KR, TERRITORY_RUS,
        3, TERRITORY_RU_MUR, TERRITORY_RU_KR, TERRITORY_RUS,
        45775000, 2509,
        87550000, 2293,
        37135000, 2159,
        66867226, 2141,
        32796250, 2115,
        43200000, 2108,
        7, TERRITORY_ISR, TERRITORY_PSE, TERRITORY_JOR, TERRITORY_SYR, TERRITORY_IRQ, TERRITORY_EGY, TERRITORY_SAU,
        6, TERRITORY_KWT, TERRITORY_IRQ, TERRITORY_AFG, TERRITORY_PAK, TERRITORY_IRN, TERRITORY_SAU,
        43200000, 2134,
        35253300, 2130,
        37709800, 2126,
        4, TERRITORY_LBN, TERRITORY_ISR, TERRITORY_JOR, TERRITORY_SYR,
        3, TERRITORY_JOR, TERRITORY_SYR, TERRITORY_IRQ,
        3, TERRITORY_SYR, TERRITORY_IRQ, TERRITORY_TUR,
        6, TERRITORY_IRQ, TERRITORY_TKM, TERRITORY_AFG, TERRITORY_TUR, TERRITORY_PAK, TERRITORY_IRN,
        17, TERRITORY_TJK, TERRITORY_NPL, TERRITORY_AFG, TERRITORY_PAK, TERRITORY_IN_CH, TERRITORY_IN_DL,
        TERRITORY_IN_PB, TERRITORY_IN_HR, TERRITORY_IN_UT, TERRITORY_IN_HP, TERRITORY_IN_JK, TERRITORY_IN_RJ,
        TERRITORY_IN_UP, TERRITORY_IND, TERRITORY_CN_XZ, TERRITORY_CN_XJ, TERRITORY_CHN,
        46099000, 2246,
        42291500, 2190,
        42910000, 2175,
        39220000, 2171,
        3, TERRITORY_SYR, TERRITORY_IRQ, TERRITORY_TUR,
        3, TERRITORY_GEO, TERRITORY_TUR, TERRITORY_RUS,
        40420000, 2183,
        5, TERRITORY_ARM, TERRITORY_AZE, TERRITORY_IRQ, TERRITORY_TUR, TERRITORY_IRN,
        6, TERRITORY_ARM, TERRITORY_GEO, TERRITORY_AZE, TERRITORY_TUR, TERRITORY_RU_DA, TERRITORY_RUS,
        44476450, 2230,
        44203226, 2216,
        42073685, 2209,
        43622500, 2203,
        4, TERRITORY_GEO, TERRITORY_RU_KC, TERRITORY_RU_KDA, TERRITORY_RUS,
        5, TERRITORY_RU_AD, TERRITORY_RU_KC, TERRITORY_RU_STA, TERRITORY_RU_KDA, TERRITORY_RUS,
        6, TERRITORY_GEO, TERRITORY_RU_SE, TERRITORY_RU_KB, TERRITORY_RU_KC, TERRITORY_RU_STA, TERRITORY_RUS,
        40808500, 2224,
        5, TERRITORY_UKR, TERRITORY_RU_AD, TERRITORY_RU_KC, TERRITORY_RU_KDA, TERRITORY_RUS,
        5, TERRITORY_RU_KC, TERRITORY_RU_STA, TERRITORY_RU_KDA, TERRITORY_RU_KL, TERRITORY_RUS,
        44337000, 2240,
        7, TERRITORY_GEO, TERRITORY_RU_IN, TERRITORY_RU_SE, TERRITORY_RU_CE, TERRITORY_RU_DA, TERRITORY_RU_STA,
        TERRITORY_RUS,
        5, TERRITORY_RU_AST, TERRITORY_RU_DA, TERRITORY_RU_STA, TERRITORY_RU_KL, TERRITORY_RUS,
        40175000, 2266,
        66867226, 2258,
        7, TERRITORY_ARM, TERRITORY_AZE, TERRITORY_IRQ, TERRITORY_UZB, TERRITORY_TKM, TERRITORY_AFG, TERRITORY_IRN,
        7, TERRITORY_TJK, TERRITORY_KGZ, TERRITORY_UZB, TERRITORY_AFG, TERRITORY_IND, TERRITORY_CN_XJ, TERRITORY_CHN,
        51615000, 2284,
        44337000, 2278,
        7, TERRITORY_ARM, TERRITORY_GEO, TERRITORY_AZE, TERRITORY_KAZ, TERRITORY_RU_CE, TERRITORY_RU_DA, TERRITORY_RUS,
        5, TERRITORY_KAZ, TERRITORY_RU_AST, TERRITORY_RU_DA, TERRITORY_RU_KL, TERRITORY_RUS,
        8, TERRITORY_TJK, TERRITORY_KGZ, TERRITORY_UZB, TERRITORY_TKM, TERRITORY_KAZ, TERRITORY_RUS, TERRITORY_CN_XJ,
        TERRITORY_CHN,
        34345000, 2377,
        108695500, 2337,
        30992500, 2320,
        97458000, 2311,
        9, TERRITORY_BTN, TERRITORY_NPL, TERRITORY_MMR, TERRITORY_IN_SK, TERRITORY_IN_AR, TERRITORY_IND,
        TERRITORY_CN_SC, TERRITORY_CN_XZ, TERRITORY_CHN,
        8, TERRITORY_MMR, TERRITORY_CN_CQ, TERRITORY_CN_GZ, TERRITORY_CN_HB, TERRITORY_CN_SC, TERRITORY_CN_YN,
        TERRITORY_CN_XZ, TERRITORY_CHN,
        104198500, 2330,
        7, TERRITORY_IND, TERRITORY_CN_SC, TERRITORY_CN_XZ, TERRITORY_CN_GS, TERRITORY_CN_QH, TERRITORY_CN_XJ,
        TERRITORY_CHN,
        6, TERRITORY_CN_CQ, TERRITORY_CN_HB, TERRITORY_CN_SN, TERRITORY_CN_SC, TERRITORY_CN_GS, TERRITORY_CHN,
        30428000, 2357,
        114600000, 2348,
        6, TERRITORY_CN_CQ, TERRITORY_CN_JX, TERRITORY_CN_GZ, TERRITORY_CN_HB, TERRITORY_CN_HN, TERRITORY_CHN,
        8, TERRITORY_JPN, TERRITORY_USA, TERRITORY_CN_ZJ, TERRITORY_CN_FJ, TERRITORY_CN_AH, TERRITORY_CN_JX,
        TERRITORY_CN_HB, TERRITORY_CHN,
        117345000, 2368,
        8, TERRITORY_CN_CQ, TERRITORY_CN_JS, TERRITORY_CN_AH, TERRITORY_CN_HA, TERRITORY_CN_HB, TERRITORY_CN_SN,
        TERRITORY_CN_GS, TERRITORY_CHN,
        8, TERRITORY_KOR, TERRITORY_JPN, TERRITORY_USA, TERRITORY_CN_SH, TERRITORY_CN_ZJ, TERRITORY_CN_JS,
        TERRITORY_CN_AH, TERRITORY_CHN,
        118437543, 2456,
        37349928, 2401,
        109480000, 2392,
        8, TERRITORY_IND, TERRITORY_CN_NX, TERRITORY_CN_SN, TERRITORY_CN_XZ, TERRITORY_CN_GS, TERRITORY_CN_QH,
        TERRITORY_CN_XJ, TERRITORY_CHN,
        8, TERRITORY_CN_JS, TERRITORY_CN_AH, TERRITORY_CN_SD, TERRITORY_CN_SX, TERRITORY_CN_HA, TERRITORY_CN_HE,
        TERRITORY_CN_SN, TERRITORY_CHN,
        112356000, 2427,
        40901000, 2420,
        103695000, 2413,
        5, TERRITORY_CN_NM, TERRITORY_CN_GS, TERRITORY_CN_QH, TERRITORY_CN_XJ, TERRITORY_CHN,
        6, TERRITORY_CN_NX, TERRITORY_CN_SX, TERRITORY_CN_SN, TERRITORY_CN_NM, TERRITORY_CN_GS, TERRITORY_CHN,
        6, TERRITORY_MNG, TERRITORY_RUS, TERRITORY_CN_NM, TERRITORY_CN_GS, TERRITORY_CN_XJ, TERRITORY_CHN,
        40901000, 2449,
        114672500, 2436,
        4, TERRITORY_CN_SX, TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CHN,
        38485000, 2443,
        4, TERRITORY_CN_SD, TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CHN,
        5, TERRITORY_CN_TJ, TERRITORY_CN_BJ, TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CHN,
        6, TERRITORY_MNG, TERRITORY_RUS, TERRITORY_CN_BJ, TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CHN,
        38662500, 2486,
        123555000, 2479,
        35585500, 2473,
        122563000, 2469,
        4, TERRITORY_CN_JS, TERRITORY_CN_AH, TERRITORY_CN_SD, TERRITORY_CHN,
        3, TERRITORY_JPN, TERRITORY_CN_SD, TERRITORY_CHN,
        5, TERRITORY_JPN, TERRITORY_CN_SD, TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CHN,
        6, TERRITORY_KOR, TERRITORY_PRK, TERRITORY_JPN, TERRITORY_USA, TERRITORY_CN_NM, TERRITORY_CHN,
        128256500, 2499,
        10, TERRITORY_PRK, TERRITORY_JPN, TERRITORY_MNG, TERRITORY_RUS, TERRITORY_CN_LN, TERRITORY_CN_JL,
        TERRITORY_CN_HE, TERRITORY_CN_NM, TERRITORY_CN_HL, TERRITORY_CHN,
        9, TERRITORY_PRK, TERRITORY_JPN, TERRITORY_USA, TERRITORY_RU_SAK, TERRITORY_RU_PO, TERRITORY_RUS,
        TERRITORY_CN_JL, TERRITORY_CN_HL, TERRITORY_CHN,
        50981650, 2748,
        54414000, 2613,
        40807800, 2559,
        52698500, 2529,
        11, TERRITORY_UKR, TERRITORY_RU_LIP, TERRITORY_RU_ORL, TERRITORY_RU_BE, TERRITORY_RU_KRS, TERRITORY_RU_TT,
        TERRITORY_RU_BRY, TERRITORY_RU_VOR, TERRITORY_RU_KDA, TERRITORY_RU_ROS, TERRITORY_RUS,
        37499000, 2539,
        7, TERRITORY_RU_ORL, TERRITORY_RU_TUL, TERRITORY_RU_KLU, TERRITORY_RU_BRY, TERRITORY_RU_MOS, TERRITORY_RU_SMO,
        TERRITORY_RUS,
        54038750, 2554,
        39434000, 2549,
        5, TERRITORY_RU_LIP, TERRITORY_RU_ORL, TERRITORY_RU_TUL, TERRITORY_RU_RYA, TERRITORY_RUS,
        4, TERRITORY_RU_LIP, TERRITORY_RU_TT, TERRITORY_RU_RYA, TERRITORY_RUS,
        4, TERRITORY_RU_TUL, TERRITORY_RU_RYA, TERRITORY_RU_MOS, TERRITORY_RUS,
        51418000, 2593,
        44647865, 2578,
        48918000, 2572,
        6, TERRITORY_RU_STA, TERRITORY_RU_KDA, TERRITORY_RU_KL, TERRITORY_RU_ROS, TERRITORY_RU_VGG, TERRITORY_RUS,
        5, TERRITORY_RU_VOR, TERRITORY_RU_ROS, TERRITORY_RU_VGG, TERRITORY_RU_SAR, TERRITORY_RUS,
        49334500, 2587,
        6, TERRITORY_KAZ, TERRITORY_RU_AST, TERRITORY_RU_STA, TERRITORY_RU_KL, TERRITORY_RU_VGG, TERRITORY_RUS,
        5, TERRITORY_KAZ, TERRITORY_RU_VGG, TERRITORY_RU_ORE, TERRITORY_RU_SAR, TERRITORY_RUS,
        47108750, 2605,
        9, TERRITORY_KAZ, TERRITORY_RU_TT, TERRITORY_RU_RYA, TERRITORY_RU_VOR, TERRITORY_RU_MO, TERRITORY_RU_PNZ,
        TERRITORY_RU_ULY, TERRITORY_RU_SAR, TERRITORY_RUS,
        7, TERRITORY_KAZ, TERRITORY_RU_ORE, TERRITORY_RU_ULY, TERRITORY_RU_TA, TERRITORY_RU_SAM, TERRITORY_RU_SAR,
        TERRITORY_RUS,
        41592250, 2687,
        57125500, 2650,
        38123500, 2635,
        56301000, 2629,
        7, TERRITORY_RU_MOW, TERRITORY_RU_TUL, TERRITORY_RU_KLU, TERRITORY_RU_MOS, TERRITORY_RU_SMO, TERRITORY_RU_TVE,
        TERRITORY_RUS,
        5, TERRITORY_RU_YAR, TERRITORY_RU_MOS, TERRITORY_RU_NGR, TERRITORY_RU_TVE, TERRITORY_RUS,
        55500500, 2643,
        5, TERRITORY_RU_TUL, TERRITORY_RU_VLA, TERRITORY_RU_RYA, TERRITORY_RU_MOS, TERRITORY_RUS,
        6, TERRITORY_RU_IVA, TERRITORY_RU_VLA, TERRITORY_RU_YAR, TERRITORY_RU_MOS, TERRITORY_RU_TVE, TERRITORY_RUS,
        38853500, 2674,
        60039500, 2667,
        36659000, 2662,
        5, TERRITORY_RU_NGR, TERRITORY_RU_TVE, TERRITORY_RU_LEN, TERRITORY_RU_VLG, TERRITORY_RUS,
        4, TERRITORY_RU_YAR, TERRITORY_RU_TVE, TERRITORY_RU_VLG, TERRITORY_RUS,
        6, TERRITORY_RU_LEN, TERRITORY_RU_VLG, TERRITORY_RU_MUR, TERRITORY_RU_KR, TERRITORY_RU_ARK, TERRITORY_RUS,
        60132500, 2682,
        5, TERRITORY_RU_IVA, TERRITORY_RU_YAR, TERRITORY_RU_KOS, TERRITORY_RU_VLG, TERRITORY_RUS,
        4, TERRITORY_RU_VLG, TERRITORY_RU_MUR, TERRITORY_RU_ARK, TERRITORY_RUS,
        56340000, 2715,
        44301100, 2697,
        5, TERRITORY_RU_VLA, TERRITORY_RU_RYA, TERRITORY_RU_MO, TERRITORY_RU_NIZ, TERRITORY_RUS,
        55638350, 2708,
        8, TERRITORY_KAZ, TERRITORY_RU_CU, TERRITORY_RU_MO, TERRITORY_RU_NIZ, TERRITORY_RU_ULY, TERRITORY_RU_TA,
        TERRITORY_RU_SAM, TERRITORY_RUS,
        6, TERRITORY_RU_CU, TERRITORY_RU_NIZ, TERRITORY_RU_KI, TERRITORY_RU_ME, TERRITORY_RU_TA, TERRITORY_RUS,
        44353250, 2731,
        58284000, 2725,
        5, TERRITORY_RU_IVA, TERRITORY_RU_VLA, TERRITORY_RU_KOS, TERRITORY_RU_NIZ, TERRITORY_RUS,
        5, TERRITORY_RU_KOS, TERRITORY_RU_VLG, TERRITORY_RU_NEN, TERRITORY_RU_ARK, TERRITORY_RUS,
        58284000, 2740,
        6, TERRITORY_RU_KOS, TERRITORY_RU_NIZ, TERRITORY_RU_KI, TERRITORY_RU_ME, TERRITORY_RU_TA, TERRITORY_RUS,
        7, TERRITORY_RU_KOS, TERRITORY_RU_VLG, TERRITORY_RU_NEN, TERRITORY_RU_KO, TERRITORY_RU_ARK, TERRITORY_RU_KI,
        TERRITORY_RUS,
        54913550, 2793,
        96800500, 2773,
        20, TERRITORY_MNG, TERRITORY_KAZ, TERRITORY_RU_ORE, TERRITORY_RU_BA, TERRITORY_RU_TA, TERRITORY_RU_SAM,
        TERRITORY_RU_KGN, TERRITORY_RU_CH, TERRITORY_RU_IRK, TERRITORY_RU_NVS, TERRITORY_RU_OMS, TERRITORY_RU_KK,
        TERRITORY_RU_KEM, TERRITORY_RU_AL, TERRITORY_RU_ALT, TERRITORY_RU_TY, TERRITORY_RU_KYA, TERRITORY_RUS,
        TERRITORY_CN_XJ, TERRITORY_CHN,
        19, TERRITORY_MNG, TERRITORY_US_AK, TERRITORY_USA, TERRITORY_RU_BU, TERRITORY_RU_ZAB, TERRITORY_RU_IRK,
        TERRITORY_RU_TY, TERRITORY_RU_KYA, TERRITORY_RU_KAM, TERRITORY_RU_SAK, TERRITORY_RU_PO, TERRITORY_RU_YEV,
        TERRITORY_RU_KHA, TERRITORY_RU_AMU, TERRITORY_RUS, TERRITORY_CN_JL, TERRITORY_CN_NM, TERRITORY_CN_HL,
        TERRITORY_CHN,
        80381500, 2880,
        58577500, 2840,
        64084850, 2830,
        55653700, 2814,
        60983000, 2809,
        5, TERRITORY_KAZ, TERRITORY_RU_BA, TERRITORY_RU_TA, TERRITORY_RU_CH, TERRITORY_RUS,
        4, TERRITORY_KAZ, TERRITORY_RU_KGN, TERRITORY_RU_CH, TERRITORY_RUS,
        55784200, 2823,
        6, TERRITORY_RU_KI, TERRITORY_RU_PM, TERRITORY_RU_BA, TERRITORY_RU_UD, TERRITORY_RU_TA, TERRITORY_RUS,
        6, TERRITORY_RU_PM, TERRITORY_RU_BA, TERRITORY_RU_SVE, TERRITORY_RU_KGN, TERRITORY_RU_CH, TERRITORY_RUS,
        9, TERRITORY_KAZ, TERRITORY_RU_SVE, TERRITORY_RU_TYU, TERRITORY_RU_KGN, TERRITORY_RU_NVS, TERRITORY_RU_TOM,
        TERRITORY_RU_OMS, TERRITORY_RU_KYA, TERRITORY_RUS,
        72088350, 2867,
        62076000, 2860,
        55581500, 2852,
        5, TERRITORY_RU_KO, TERRITORY_RU_ARK, TERRITORY_RU_KI, TERRITORY_RU_PM, TERRITORY_RUS,
        7, TERRITORY_RU_KO, TERRITORY_RU_ARK, TERRITORY_RU_PM, TERRITORY_RU_KM, TERRITORY_RU_SVE, TERRITORY_RU_TYU,
        TERRITORY_RUS,
        6, TERRITORY_RU_NEN, TERRITORY_RU_KO, TERRITORY_RU_ARK, TERRITORY_RU_YAN, TERRITORY_RU_KM, TERRITORY_RUS,
        61617000, 2875,
        5, TERRITORY_RU_KM, TERRITORY_RU_TYU, TERRITORY_RU_TOM, TERRITORY_RU_KYA, TERRITORY_RUS,
        4, TERRITORY_RU_YAN, TERRITORY_RU_KM, TERRITORY_RU_KYA, TERRITORY_RUS,
        58509500, 2904,
        93798000, 2892,
        7, TERRITORY_KAZ, TERRITORY_RU_NVS, TERRITORY_RU_TOM, TERRITORY_RU_KK, TERRITORY_RU_KEM, TERRITORY_RU_KYA,
        TERRITORY_RUS,
        11, TERRITORY_US_AK, TERRITORY_USA, TERRITORY_RU_BU, TERRITORY_RU_ZAB, TERRITORY_RU_IRK, TERRITORY_RU_KYA,
        TERRITORY_RU_KAM, TERRITORY_RU_KHA, TERRITORY_RU_AMU, TERRITORY_RU_SA, TERRITORY_RUS,
        125763055, 2914,
        7, TERRITORY_RU_YAN, TERRITORY_RU_KM, TERRITORY_RU_IRK, TERRITORY_RU_TOM, TERRITORY_RU_KYA, TERRITORY_RU_SA,
        TERRITORY_RUS,
        8, TERRITORY_US_AK, TERRITORY_USA, TERRITORY_RU_MAG, TERRITORY_RU_CHU, TERRITORY_RU_KAM, TERRITORY_RU_KHA,
        TERRITORY_RU_SA, TERRITORY_RUS,
        0
}; // 2924 records, data version 2.3.0

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_SEARCH_H__
