// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_RU_H__
#define __INTERNAL_TERRITORY_NAMES_RU_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_RU[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_RU // Russian
        /*     VAT */ "Город Ватикан|Святейший Престол",
        /*     MCO */ "Монако",
        /*     GIB */ "Гибралтар",
        /*     TKL */ "Токелау",
        /*     CCK */ "Кокосовые острова|Килинг острова",
        /*     BLM */ "Сен-Бартельми",
        /*     NRU */ "Науру",
        /*     TUV */ "Тувалу",
        /*     MAC */ "Макао",
        /*     SXM */ "Синт-Маартен",
        /*     MAF */ "Сен-Мартен",
        /*     NFK */ "Норфолк и Филип-Айленд|Филип-Айленд",
        /*     PCN */ "Питкэрн",
        /*     BVT */ "Остров Буве",
        /*     BMU */ "Бермудские острова|Бермуды",
        /*     IOT */ "Британская территория Индийского океана",
        /*     SMR */ "Сан - Марино",
        /*     GGY */ "Гернси",
        /*     AIA */ "Ангилья",
        /*     MSR */ "Монсеррат",
        /*     JEY */ "Джерси",
        /*     CXR */ "Остров Рождества",
        /*     WLF */ "Уоллис и Футуна|Южная Африка",
        /*     VGB */ "Британские Виргинские острова|Виргинские острова, Британские",
        /*     LIE */ "Лихтенштейн",
        /*     ABW */ "Аруба",
        /*     MHL */ "Маршалловы острова",
        /*     ASM */ "Американское Самоа|Самоа, Американское",
        /*     COK */ "Острова Кука",
        /*     SPM */ "Сен-Пьер и Микелон|Микелон",
        /*     NIU */ "Ниуэ",
        /*     KNA */ "Сент-Китс и Невис|Невис",
        /*     CYM */ "Каймановы острова",
        /*     BES */ "Бонайре, Сент-Эстатиус и Саба|Саба|Сент-Эстатиус",
        /*     MDV */ "Мальдивы",
        /*     SHN */ "Святой Елены, Вознесения и Тристан-да-Кунья|Вознесение|Тристан-да-Кунья",
        /*     MLT */ "Мальта",
        /*     GRD */ "Гренада",
        /*     VIR */ "Американские Виргинские острова|Виргинские острова, США",
        /*     MYT */ "Майотта",
        /*     SJM */ "Шпицберген и Ян-Майен|Ян-Майен",
        /*     VCT */ "Сент-Винсент и Гренадины|Гренадины",
        /*     HMD */ "Остров Херд и острова Макдональд|Макдональд",
        /*     BRB */ "Барбадос",
        /*     ATG */ "Антигуа и Барбуда|Барбуда",
        /*     CUW */ "ликер кюрасо",
        /*     SYC */ "Сейшельские острова",
        /*     PLW */ "Палау",
        /*     MNP */ "Северные Марианские острова",
        /*     AND */ "андорра",
        /*     GUM */ "Гуам",
        /*     IMN */ "Остров Мэн",
        /*     LCA */ "Санкт-Люсия",
        /*     FSM */ "Микронезия|Федеративные Штаты Микронезии",
        /*     SGP */ "Сингапур",
        /*     TON */ "Тонга",
        /*     DMA */ "Доминика",
        /*     BHR */ "Бахрейн",
        /*     KIR */ "Кирибати",
        /*     TCA */ "Острова Теркс и Кайкос|Кайкос",
        /*     STP */ "Сан-Томе и Принсипи|Принсипи",
        /*     HKG */ "Гонконг",
        /*     MTQ */ "Мартиника",
        /*     FRO */ "Фарерские острова",
        /*     GLP */ "Гваделупа",
        /*     COM */ "Коморские острова",
        /*     MUS */ "Маврикий",
        /*     REU */ "воссоединение",
        /*     LUX */ "Люксембург",
        /*     WSM */ "Самоа",
        /*     SGS */ "Южная Джорджия и Южные Сандвичевы острова|Южные Сандвичевы острова",
        /*     PYF */ "Французская Полинезия",
        /*     CPV */ "Кабо-Верде",
        /*     TTO */ "Тринидад и Тобаго|Тобаго",
        /*     BRN */ "Бруней",
        /*     ATF */ "Французские Южные и Антарктические земли",
        /*     PRI */ "Пуэрто-Рико",
        /*     CYP */ "Кипр",
        /*     LBN */ "Ливан",
        /*     JAM */ "Ямайка",
        /*     GMB */ "Гамбия",
        /*     QAT */ "Катар",
        /*     FLK */ "Фолклендские острова",
        /*     VUT */ "Вануату",
        /*     MNE */ "Черногория",
        /*     BHS */ "Багамские о-ва",
        /*     TLS */ "Восточный Тимор",
        /*     SWZ */ "Свазиленд",
        /*     KWT */ "Кувейт",
        /*     FJI */ "Фиджи|острова Фиджи",
        /*     NCL */ "Новая Каледония",
        /*     SVN */ "Словения",
        /*     ISR */ "Израиль",
        /*     PSE */ "Территории Палестины",
        /*     SLV */ "Сальвадор",
        /*     BLZ */ "Белиз",
        /*     DJI */ "Джибути",
        /*     MKD */ "Македония",
        /*     RWA */ "Руанда",
        /*     HTI */ "Гаити",
        /*     BDI */ "Бурунди",
        /*     GNQ */ "Экваториальная Гвинея",
        /*     ALB */ "Албания",
        /*     SLB */ "Соломоновы острова",
        /*     ARM */ "Армения",
        /*     LSO */ "Лесото",
        /*     BEL */ "Бельгия",
        /*     MDA */ "Молдова",
        /*     GNB */ "Гвинея-Бисау",
        /*     TWN */ "Тайвань",
        /*     BTN */ "Бутан",
        /*     CHE */ "Швейцария",
        /*     NLD */ "Нидерланды",
        /*     DNK */ "Дания",
        /*     EST */ "Эстония",
        /*     DOM */ "Доминиканская Республика",
        /*     SVK */ "Словакия",
        /*     CRI */ "Коста-Рика",
        /*     BIH */ "Босния и Герцеговина",
        /*     HRV */ "Хорватия",
        /*     TGO */ "Того",
        /*     LVA */ "Латвия",
        /*     LTU */ "Литва",
        /*     LKA */ "Шри Ланка",
        /*     GEO */ "Грузия",
        /*     IRL */ "Ирландия",
        /*     SLE */ "Сьерра-Леоне",
        /*     PAN */ "Панама",
        /*     CZE */ "Чешская Республика",
        /*     GUF */ "Французская Гвиана",
        /*     ARE */ "Объединенные Арабские Эмираты",
        /*     AUT */ "Австрия",
        /*     AZE */ "Азербайджан",
        /*     SRB */ "Сербия",
        /*     JOR */ "Иордания",
        /*     PRT */ "Португалия",
        /*     HUN */ "Венгрия",
        /*     KOR */ "Южная Корея",
        /*     ISL */ "Исландия",
        /*     GTM */ "Гватемала",
        /*     CUB */ "Куба",
        /*     BGR */ "Болгария",
        /*     LBR */ "Либерия",
        /*     HND */ "Гондурас",
        /*     BEN */ "Бенин",
        /*     ERI */ "Эритрея",
        /*     MWI */ "Малави",
        /*     PRK */ "Северная Корея",
        /*     NIC */ "Никарагуа",
        /*     GRC */ "Греция",
        /*     TJK */ "Таджикистан",
        /*     BGD */ "Бангладеш",
        /*     NPL */ "Непал",
        /*     TUN */ "Тунис",
        /*     SUR */ "Суринам",
        /*     URY */ "Уругвай",
        /*     KHM */ "Камбоджа",
        /*     SYR */ "Сирия",
        /*     SEN */ "Сенегал",
        /*     KGZ */ "Киргизия",
        /*     BLR */ "Беларусь",
        /*     GUY */ "Гайана",
        /*     LAO */ "Лаос",
        /*     ROU */ "Румыния",
        /*     GHA */ "Гана",
        /*     UGA */ "Уганда",
        /*     GBR */ "Соединенное Королевство|Шотландия|Великобритания|Северная Ирландия|Ирландия, Северная",
        /*     GIN */ "Гвинея",
        /*     ECU */ "Эквадор",
        /*     ESH */ "Западная Сахара|сахрави",
        /*     GAB */ "Габон",
        /*     NZL */ "Новая Зеландия",
        /*     BFA */ "Буркина-Фасо",
        /*     PHL */ "Филиппины",
        /*     ITA */ "Италия",
        /*     OMN */ "Оман",
        /*     POL */ "Польша",
        /*     CIV */ "Кот-д`Ивуар",
        /*     NOR */ "Норвегия",
        /*     MYS */ "Малайзия",
        /*     VNM */ "Вьетнам",
        /*     FIN */ "Финляндия",
        /*     COG */ "Конго-Браззавиль",
        /*     DEU */ "Германия",
        /*     JPN */ "Япония",
        /*     ZWE */ "Зимбабве",
        /*     PRY */ "Парагвай",
        /*     IRQ */ "Ирак",
        /*     MAR */ "Марокко",
        /*     UZB */ "Узбекистан",
        /*     SWE */ "Швеция",
        /*     PNG */ "Папуа - Новая Гвинея",
        /*     CMR */ "Камерун",
        /*     TKM */ "Туркменистан",
        /*     ESP */ "Испания",
        /*     THA */ "Таиланд",
        /*     YEM */ "Йемен",
        /*     FRA */ "Франция",
        /*     ALA */ "Аландские острова",
        /*     KEN */ "Кения",
        /*     BWA */ "Ботсвана",
        /*     MDG */ "Мадагаскар",
        /*     UKR */ "Украина",
        /*     SSD */ "южный Судан",
        /*     CAF */ "Центрально-Африканская Республика",
        /*     SOM */ "Сомали",
        /*     AFG */ "Афганистан",
        /*     MMR */ "Мьянма|Бирма",
        /*     ZMB */ "Замбия",
        /*     CHL */ "Чили",
        /*     TUR */ "Турция",
        /*     PAK */ "Пакистан",
        /*     MOZ */ "Мозамбик",
        /*     NAM */ "Намибия",
        /*     VEN */ "Венесуэла",
        /*     NGA */ "Нигерия",
        /*     TZA */ "Танзания",
        /*     EGY */ "Египет",
        /*     MRT */ "Мавритания",
        /*     BOL */ "Боливия",
        /*     ETH */ "Эфиопия",
        /*     COL */ "Колумбия",
        /*     ZAF */ "Южная Африка",
        /*     MLI */ "Мали",
        /*     AGO */ "Ангола",
        /*     NER */ "Нигер",
        /*     TCD */ "Чад",
        /*     PER */ "Перу",
        /*     MNG */ "Монголия",
        /*     IRN */ "Я побежал",
        /*     LBY */ "Ливия",
        /*     SDN */ "Судан",
        /*     IDN */ "Индонезия",
        /*     DIF */ "Федеральный район",
        /*     TLA */ "Тлашкала",
        /*     MOR */ "Морелос",
        /*     AGU */ "Агуаскальентес",
        /*   MX-CL */ "Колима",
        /*     QUE */ "Керетаро",
        /*     HID */ "Идальго",
        /*   MX-MX */ "Штат Мексика",
        /*     TAB */ "табаско",
        /*     NAY */ "Наярит",
        /*     GUA */ "Гуанахуато",
        /*     PUE */ "Пуэбла",
        /*     YUC */ "Юкатан",
        /*     ROO */ "Кинтана-Роо",
        /*     SIN */ "Синалоа",
        /*     CAM */ "Кампече",
        /*     MIC */ "Мичоакан",
        /*     SLP */ "Сан - Луис-Потоси",
        /*     GRO */ "Герреро",
        /*     NLE */ "Нуэво-Леон",
        /*     BCN */ "Нижняя Калифорния",
        /*     VER */ "Веракрус",
        /*     CHP */ "Чьяпас",
        /*     BCS */ "Южная Нижняя Калифорния",
        /*     ZAC */ "Сакатекас",
        /*     JAL */ "Халиско",
        /*     TAM */ "Тамаулипас",
        /*     OAX */ "Оахака",
        /*     DUR */ "Дуранго",
        /*     COA */ "Коахуила",
        /*     SON */ "Сонора",
        /*     CHH */ "Чихуахуа",
        /*     GRL */ "Гренландия",
        /*     SAU */ "Саудовская Аравия",
        /*     COD */ "Конго-Киншаса",
        /*     DZA */ "Алжир",
        /*     KAZ */ "Казахстан",
        /*     ARG */ "Аргентина",
        /*   IN-DD */ "Даман и Диу",
        /*   IN-DN */ "Дадра и Нагархавели",
        /*   IN-CH */ "Чандигарх",
        /*   IN-AN */ "Андаманские и Никобарские",
        /*   IN-LD */ "Лакшадвип",
        /*   IN-DL */ "Дели",
        /*   IN-ML */ "Мегхалая",
        /*   IN-NL */ "Нагаленд",
        /*   IN-MN */ "Манипур",
        /*   IN-TR */ "Трипура",
        /*   IN-MZ */ "Мизорам",
        /*   IN-SK */ "Сикким",
        /*   IN-PB */ "Пенджаб",
        /*   IN-HR */ "Харьяна",
        /*   IN-AR */ "Аруначал-Прадеш",
        /*   IN-AS */ "Ассам",
        /*   IN-BR */ "Бихар",
        /*   IN-UT */ "Уттаракханд",
        /*   IN-GA */ "Гоа",
        /*   IN-KL */ "Керала",
        /*   IN-TN */ "Тамилнад",
        /*   IN-HP */ "Химачал-Прадеш",
        /*   IN-JK */ "Джамму и Кашмир",
        /*   IN-CT */ "Чхаттисгарх",
        /*   IN-JH */ "Джаркханд",
        /*   IN-KA */ "Карнатака",
        /*   IN-RJ */ "Раджастхан",
        /*   IN-OR */ "Орисса",
        /*   IN-GJ */ "Гуджарат",
        /*   IN-WB */ "Западная Бенгалия",
        /*   IN-MP */ "Мадхья-Прадеш",
        /*   IN-TG */ "Телингана",
        /*   IN-AP */ "Андхра-Прадеш",
        /*   IN-MH */ "Махараштра",
        /*   IN-UP */ "Уттар-Прадеш",
        /*   IN-PY */ "Пондичерри",
        /*     NSW */ "Новый Южный Уэльс",
        /*     ACT */ "территория столицы Австралии",
        /*     JBT */ "Территория Джервис-Бей",
        /*   AU-NT */ "Северная территория",
        /*   AU-SA */ "Южная Австралия",
        /*     TAS */ "Тасмания",
        /*     VIC */ "Виктория",
        /*   AU-WA */ "Западная Австралия",
        /*     QLD */ "Квинсленд",
        /*   BR-DF */ "Федеральный округ",
        /*   BR-SE */ "Сержипи",
        /*   BR-AL */ "Алагоас",
        /*   BR-RJ */ "Рио де Жанейро",
        /*   BR-ES */ "Эспириту-Санту",
        /*   BR-RN */ "Рио-Гранде-ду-Норти",
        /*   BR-PB */ "Параибы",
        /*   BR-SC */ "Санта-Катарина",
        /*   BR-PE */ "Пернамбуку",
        /*   BR-AP */ "Амапа",
        /*   BR-CE */ "Сеара",
        /*   BR-AC */ "Акри",
        /*   BR-PR */ "Парана",
        /*   BR-RR */ "Рорайма",
        /*   BR-RO */ "Рондония",
        /*   BR-SP */ "Сан-Паулу",
        /*   BR-PI */ "Пиауи",
        /*   BR-TO */ "Токантинс",
        /*   BR-RS */ "Рио-Гранде-ду-Сул",
        /*   BR-MA */ "Мараньян",
        /*   BR-GO */ "Гояс",
        /*   BR-MS */ "Мату-Гросу-ду-Сул",
        /*   BR-BA */ "Баия",
        /*   BR-MG */ "Минас-Жерайс",
        /*   BR-MT */ "Мату-Гросу",
        /*   BR-PA */ "Пара",
        /*   BR-AM */ "Амазонас",
        /*   US-DC */ "Округ Колумбия",
        /*   US-RI */ "Род-Айленд",
        /*   US-DE */ "Делавэр",
        /*   US-CT */ "Коннектикут",
        /*   US-NJ */ "Нью-Джерси",
        /*   US-NH */ "Нью-Гемпшир",
        /*   US-VT */ "Вермонт",
        /*   US-MA */ "Массачусетс",
        /*   US-HI */ "Гавайи",
        /*   US-MD */ "Мэриленд",
        /*   US-WV */ "Западная Виргиния",
        /*   US-SC */ "Южная Каролина",
        /*   US-ME */ "Мэн",
        /*   US-IN */ "Индиана",
        /*   US-KY */ "Кентукки",
        /*   US-TN */ "Теннесси",
        /*   US-VA */ "Виргиния",
        /*   US-OH */ "Огайо",
        /*   US-PA */ "Пенсильвания",
        /*   US-MS */ "Миссисипи",
        /*   US-LA */ "Луизиана",
        /*   US-AL */ "Алабама",
        /*   US-AR */ "Арканзас",
        /*   US-NC */ "Северная Каролина",
        /*   US-NY */ "Нью-Йорк",
        /*   US-IA */ "Айова",
        /*   US-IL */ "Иллинойс",
        /*   US-GA */ "Грузия",
        /*   US-WI */ "Висконсин",
        /*   US-FL */ "Флорида",
        /*   US-MO */ "Миссури",
        /*   US-OK */ "Оклахома",
        /*   US-ND */ "Северная Дакота",
        /*   US-WA */ "Вашингтон",
        /*   US-SD */ "Южная Дакота",
        /*   US-NE */ "Небраска",
        /*   US-KS */ "Канзас",
        /*   US-ID */ "Айдахо",
        /*   US-UT */ "Юта",
        /*   US-MN */ "Миннесота",
        /*   US-MI */ "Мичиган",
        /*   US-WY */ "Вайоминг",
        /*   US-OR */ "Орегон",
        /*   US-CO */ "Колорадо",
        /*   US-NV */ "Невада",
        /*   US-AZ */ "Аризона",
        /*   US-NM */ "Нью-Мексико",
        /*   US-MT */ "Монтана",
        /*   US-CA */ "Калифорния",
        /*   US-TX */ "Техас",
        /*   US-AK */ "Аляска",
        /*   CA-BC */ "британская Колумбия",
        /*   CA-AB */ "альберта",
        /*   CA-ON */ "Онтарио",
        /*   CA-QC */ "Квебек",
        /*   CA-SK */ "Саскачеван",
        /*   CA-MB */ "Манитоба",
        /*   CA-NL */ "Ньюфаундленд",
        /*   CA-NB */ "Новый Брансвик",
        /*   CA-NS */ "Новая Шотландия",
        /*   CA-PE */ "Остров Принца Эдуарда",
        /*   CA-YT */ "Юкон",
        /*   CA-NT */ "Северо-западные территории",
        /*   CA-NU */ "Нунавут",
        /*     IND */ "Индия",
        /*     AUS */ "Австралия",
        /*     BRA */ "Бразилия",
        /*     USA */ "США|Соединенные Штаты Америки|Америка",
        /*     MEX */ "Мексика",
        /*     MOW */ "Москва",
        /*     SPE */ "Санкт-Петербург",
        /*     KGD */ "Калининградская область",
        /*   RU-IN */ "Республика Ингушетия",
        /*   RU-AD */ "Республика Адыгея",
        /*   RU-SE */ "Северная Осетия-Алания",
        /*   RU-KB */ "Кабардино-Балкарская Республика",
        /*   RU-KC */ "Карачаево-Черкесская Республика",
        /*   RU-CE */ "Чеченская Республика",
        /*   RU-CU */ "Чувашская Республика",
        /*     IVA */ "Ивановская область",
        /*     LIP */ "Липецкая область",
        /*     ORL */ "Орловская область",
        /*     TUL */ "Тульская область",
        /*   RU-BE */ "Белгородская область",
        /*     VLA */ "Владимирская область",
        /*     KRS */ "Курская область",
        /*     KLU */ "Калужская область",
        /*   RU-TT */ "Тамбовская область",
        /*     BRY */ "Брянская область",
        /*     YAR */ "Ярославская область",
        /*     RYA */ "Рязанская область",
        /*     AST */ "Астраханская область",
        /*     MOS */ "Московская область",
        /*     SMO */ "Смоленская область",
        /*   RU-DA */ "Республика Дагестан",
        /*     VOR */ "Воронежская область",
        /*     NGR */ "Новгородская область",
        /*     PSK */ "Псковская область",
        /*     KOS */ "Костромская область",
        /*     STA */ "Ставропольский край",
        /*     KDA */ "Краснодарский край",
        /*   RU-KL */ "Республика Калмыкия",
        /*     TVE */ "Тверская область",
        /*     LEN */ "Ленинградская область",
        /*     ROS */ "Ростовская область",
        /*     VGG */ "Волгоградская область",
        /*     VLG */ "Вологодская область",
        /*     MUR */ "Мурманская область",
        /*   RU-KR */ "Республика Карелия",
        /*     NEN */ "Ненецкий автономный округ",
        /*   RU-KO */ "Республика Коми",
        /*     ARK */ "Архангельская область",
        /*   RU-MO */ "Республика Мордовия",
        /*     NIZ */ "Нижегородская область",
        /*     PNZ */ "Пензенская область",
        /*   RU-KI */ "Кировская область",
        /*   RU-ME */ "Республика Марий Эл",
        /*     ORE */ "Оренбургская область",
        /*     ULY */ "Ульяновская область",
        /*   RU-PM */ "Пермский край",
        /*   RU-BA */ "Республика Башкортостан",
        /*   RU-UD */ "Удмуртская Республика",
        /*   RU-TA */ "Республика Татарстан",
        /*     SAM */ "Самарская область",
        /*     SAR */ "Саратовская область",
        /*     YAN */ "Ямало-Ненецкий",
        /*   RU-KM */ "Ханты-Мансийский",
        /*     SVE */ "Свердловская область",
        /*     TYU */ "Тюменская область",
        /*     KGN */ "Курганская область",
        /*   RU-CH */ "Челябинская область",
        /*   RU-BU */ "Республика Бурятия",
        /*     ZAB */ "Забайкальский край",
        /*     IRK */ "Иркутская область",
        /*     NVS */ "Новосибирская область",
        /*     TOM */ "Томская область",
        /*     OMS */ "Омская область",
        /*   RU-KK */ "Республика Хакасия",
        /*     KEM */ "Кемеровская область",
        /*   RU-AL */ "Республика Алтай",
        /*     ALT */ "Алтайский край",
        /*   RU-TY */ "Респу́блика Тыва́",
        /*     KYA */ "Красноярский край",
        /*     MAG */ "Магаданская область",
        /*     CHU */ "Чукотский округ",
        /*     KAM */ "Камчатский край",
        /*     SAK */ "Сахалинская область",
        /*   RU-PO */ "Приморский край",
        /*     YEV */ "Еврейская автономная область",
        /*     KHA */ "Хабаровский край",
        /*     AMU */ "Амурская область",
        /*   RU-SA */ "Республика Саха|Якутия",
        /*     CAN */ "Канада",
        /*     RUS */ "Россия",
        /*   CN-SH */ "Шанхай",
        /*   CN-TJ */ "Тяньцзинь",
        /*   CN-BJ */ "Пекин",
        /*   CN-HI */ "Хайнань",
        /*   CN-NX */ "Нинся-Хуэйский",
        /*   CN-CQ */ "Чунцин",
        /*   CN-ZJ */ "Чжэцзян",
        /*   CN-JS */ "Цзянсу",
        /*   CN-FJ */ "Фуцзянь",
        /*   CN-AH */ "Аньхой",
        /*   CN-LN */ "Ляонин",
        /*   CN-SD */ "Шаньдун",
        /*   CN-SX */ "Шаньси",
        /*   CN-JX */ "Цзянси",
        /*   CN-HA */ "Хэнань",
        /*   CN-GZ */ "Гуйчжоу",
        /*   CN-GD */ "Гуандун",
        /*   CN-HB */ "Хубэй",
        /*   CN-JL */ "Цзилинь",
        /*   CN-HE */ "хэбэй",
        /*   CN-SN */ "Шэньси",
        /*   CN-NM */ "Внутренняя Монголия",
        /*   CN-HL */ "Хэйлунцзян",
        /*   CN-HN */ "Хунань",
        /*   CN-GX */ "Гуанси-Чжуанский",
        /*   CN-SC */ "Сычуань",
        /*   CN-YN */ "Юньнань",
        /*   CN-XZ */ "Тибетский автономный район|Тибет",
        /*   CN-GS */ "Ганьсу",
        /*   CN-QH */ "Цинхай",
        /*   CN-XJ */ "Синьцзян-Уйгурский",
        /*     CHN */ "Китай",
        /*     UMI */ "США Внешние малые острова",
        /*     CPT */ "Остров Клиппертон",
        /*     ATA */ "Антарктида",
        /*     AAA */ "Международный|Мир|Земля"
#else // MAPCODE_SUPPORT_LANGUAGE_RU
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_RU
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_RU_H__
